@ Estimates subjects' types using information search and guesses              @
@ Uses output from guesses only estimation and output from information search @
@ only estimation, as the likelihood function is separable across guesses and @
@ information search; Tests whether estimated type does better than random    @
@ behavior. Guesses assumed to be integers as in the guesses only estimation  @

load ISE[71,8]=c:\GG_AER_2006\Estimatedloglikelihoods_early_search_alltypes.jnk;

load ISL[71,8]=c:\GG_AER_2006\Estimatedloglikelihoods_late_search_alltypes.jnk;

load GEST[88,7]=c:\GG_AER_2006\Estimatedloglikelihoods_guesses_alltypes.jnk;

GEST1=GEST~(GEST[.,1]);

GEST=GEST1[.,2:8];

@ Adds log-likelihoods for the 'early' and 'late' look-up styles @
@ according to type; Columns: 1st Subject_ID, log-likelihoods of @
@ 'early' styles (cols 2 to 8), log-likelihoods of 'late'        @
@ styles (cols 9 to 15)                                          @
SISG=zeros(71,15);

@ 'early' and 'late' type estimates: Subject_ID, 'early' type  estimate, @
@ log-likelihood of 'early' type  estimate , 'late' type  estimate,      @
@ log-likelihood of 'late' type  estimate                                @
BELT=zeros(71,5);

@ Overall type estimate: Subject_ID, Type estimate (1 to 7 - 'early' type, @
@ 8 to 15 - 'late' type), Log-likelihood of type estimate, tied type       @
OBT=zeros(71,4);

s=1;
do while s <= 71;

ty=1;
do while ty <= 7;

if ISE[s,(1+ty)]==-99;
 SISG[s,(1+ty)]=-299;
elseif ISE[s,(1+ty)]/=-99;
 SISG[s,(1+ty)]=ISE[s,(1+ty)]+GEST[s,ty];
endif;

if ISL[s,(1+ty)]==-99;
 SISG[s,(8+ty)]=-299;
elseif ISL[s,(1+ty)]/=-99;
 SISG[s,(8+ty)]=ISL[s,(1+ty)]+GEST[s,ty];
endif;

ty=ty+1;
endo;

@ Determines best early  and late look-up style types @
BELT[s,1]=ISE[s,1]*100;
BELT[s,2]=maxindc(SISG[s,2:8]');
BELT[s,3]=maxc(SISG[s,2:8]');
BELT[s,4]=maxindc(SISG[s,9:15]');
BELT[s,5]=maxc(SISG[s,9:15]');
@ Determines best overall type @
OBT[s,1]=ISE[s,1]*100;
if BELT[s,3] == BELT[s,5];
OBT[s,3]=BELT[s,3];
OBT[s,2]=BELT[s,2];
OBT[s,4]=BELT[s,4];
elseif BELT[s,3] > BELT[s,5];
OBT[s,3]=BELT[s,3];
OBT[s,2]=BELT[s,2];
elseif BELT[s,3] < BELT[s,5];
OBT[s,3]=BELT[s,5];
OBT[s,2]=BELT[s,4];
endif;

s=s+1;
endo;

@ Module to check whether type estimate does better at 5/1% level @
@ than a random model of guesses and search                       @

@ Results of a chi-squared test (estimated type vs. random behavior)  @
@ Both guesses and information search are assumed to be random        @
@ Subject_ID, test statistic, p-value                                 @
srbch=zeros(71,3);

s=1;
do while s <= 71;

SRBCH[s,1]=ISE[s,1]*100;
SRBCH[s,2]=2*(OBT[s,3] - (-98.8715875 - 17.516484));
SRBCH[s,3]=cdfchic(SRBCH[s,2],1);

s=s+1;
endo;

output file=c:\GG_AER_2006\Sum_IS_and_G.jnk reset; 

print;
print "'Early' and 'late' look-up style estimated types: Subject_ID,  ";
print "'early' type estimate, log-likelihood of 'early' type estimate,";
print "'late' type estimate, log-likelihood of 'late' type estimate   ";
BELT;
print;

print "Overall type estimate: Subject_ID, Type estimate (1 to 7 - 'early'";
print "8 to 15 - 'late' - estimated type), estimated log-likelihood, Tied Type  ";
OBT;
print;

print "Chi-square test of Estimated type vs. Random Behavior";
print " Column 1 is subject ID, Column 2 is Test Statistic, column 3 is p-value";
srbch;
print;

output off;

@ Stores estimated type's guesses-only part of the likelihood function @

bts=zeros(71,6);

s=1;
do while s <= 71;

bts[s,1]=ISE[s,1]*100;
bts[s,2]=OBT[s,2];
bts[s,3]=GEST[s,OBT[s,2]];

s=s+1;
endo;

format /m1/rd 6,2;

output file=c:\GG_AER_2006\TyEstResAGGDGOSuNOMBestTypeW1-GIS.jnk reset; 
bts; 
output off;

