@ Estimates subjects' types using Guesses                 @
@ Compliance with a type's predicted guess is (+ or -0.5) @
@ Guesses are assumed to be integers                      @

clear all;


@ MODULE 1 - computations associated with (4)'s numerator @

@ MODULE 2 - computations associated with (4)'s denominator @

@ MODULE 3 - Computes log-likelihood of each of the subjects'  @
@ guesses given each of the 7 types, identifying the best type @
@ and estimating the error rate and logit (lambda) parameters. @
@ Estimates the restricted model with lambda equal to zero.    @

@ MODULE 4 - Tests for the following restricted models      @
@ (i) epsilon equals 1; (ii) epsilon equals 1 and the logit @
@ parameter is equal to zero, for the best type found above @

@ MODULE 5 - Specification Test - Part I                            @
@ For each subject, estimates a model where each of the opponents'  @
@ guesses are assumed to be a type's guesses (pseudotype). Compares @
@ a subject's estimated type with the likelihood of a subject's     @
@ guesses given the pseudotype                                      @


@ Number of Subjects @
@ 71 Baseline Subjects, 17 Open Boxes Subjects @
pl= 88;
load A[pl,17]=c:\GG_AER_2006\SubjectsGuesses.xls;

@ Number of guesses (within 0.5) matching a type's predicted guesses @
load z[pl,8]=c:\GG_AER_2006\TYPESDTA.GGA;

@ Monetary conversion factor @
mcf=(5/16)*0.04;

@ Types' Predicted Guesses @
load TPG[16,7]=c:\GG_AER_2006\TypesGuesses.xls;
@ Column 1 is game_id, columns 2 to 7 are Eq, L1, L2, L3, D1, and D2 @
@ predicted guesses; rows (games) mumbering follows master order     @

@ Sophisticated type's predicteded guesses for pooled B+OB data @
SOTG={122 162 500 900 187 420 420 262 132 300 650 900 300 695 630 375};
      
TPG=TPG~SOTG[1,.]';

@ Some types' implied beliefs @
load TOG[16,7]=c:\GG_AER_2006\OpponentsGuesses.xls; 
@ Column 1 is game_id, col 2 is  Eq, col 3 is L1 (mid-point of opponent's @
@ allowed guesses), col 4 is L2 (L1), col 5 is L3 (L2), col 6 is D1 (mid- @
@ point of opponent's interval of adjusted guesses), col 7 is D2 (D1)     @
@ (D2 is not used. D2's beliefs are derived below)                        @

@ Lower and Upper Bounds of Undominated Guesses @
load BRD[16,11]=c:\GG_AER_2006\DominanceRounds.xls;   
@ Columns: 1st game_id, 2nd (Round 1 LB), 3rd (Round 1 UB) @
@ 4th (Round 2 LB), 5th (Round 2 UB), 6th (Round 3 LB),    @
@ 7th (Round 3 UB), 8th (Round 4 LB), 9th (Round 4 UB),    @
@ 10th (Round 5 LB), 11th (Round 5 UB)                     @

@ Number of Games @
ga=16;

@ Games: Lower and Upper Limits and Targets @

gam={100 500 0.7 100 900 0.5,
     100 900 0.5 300 500 0.7,
     300 500 1.5 300 900 1.3,
     300 900 1.3 300 900 1.3,
     100 900 0.5 100 500 1.5,
     300 900 0.7 100 900 1.3,
     300 500 0.7 100 900 1.5,
     100 500 0.7 100 500 1.5,
     100 900 0.5 100 500 0.7,
     300 500 0.7 100 900 0.5,
     300 900 1.3 300 500 1.5,
     300 900 1.3 300 900 1.3,
     100 500 1.5 100 900 0.5,
     100 900 1.3 300 900 0.7,
     100 900 1.5 300 500 0.7,
     100 500 1.5 100 500 0.7};

@ Vector (number of different own adjusted integer guesses x 1) @
pg1=zeros((gam[1,2]-gam[1,1])+1,1);
pg2=zeros((gam[2,2]-gam[2,1])+1,1);
pg3=zeros((gam[3,2]-gam[3,1])+1,1);
pg4=zeros((gam[4,2]-gam[4,1])+1,1);
pg5=zeros((gam[5,2]-gam[5,1])+1,1);
pg6=zeros((gam[6,2]-gam[6,1])+1,1);
pg7=zeros((gam[7,2]-gam[7,1])+1,1);
pg8=zeros((gam[8,2]-gam[8,1])+1,1);
pg9=zeros((gam[9,2]-gam[9,1])+1,1);
pg10=zeros((gam[10,2]-gam[10,1])+1,1);
pg11=zeros((gam[11,2]-gam[11,1])+1,1);
pg12=zeros((gam[12,2]-gam[12,1])+1,1);
pg13=zeros((gam[13,2]-gam[13,1])+1,1);
pg14=zeros((gam[14,2]-gam[14,1])+1,1);
pg15=zeros((gam[15,2]-gam[15,1])+1,1);
pg16=zeros((gam[16,2]-gam[16,1])+1,1);

@ Number of different own adjusted integer guesses @
r=zeros(16,1);
r[1]=rows(pg1);
r[2]=rows(pg2);
r[3]=rows(pg3);
r[4]=rows(pg4);
r[5]=rows(pg5);
r[6]=rows(pg6);
r[7]=rows(pg7);
r[8]=rows(pg8);
r[9]=rows(pg9);
r[10]=rows(pg10);
r[11]=rows(pg11);
r[12]=rows(pg12);
r[13]=rows(pg13);
r[14]=rows(pg14);
r[15]=rows(pg15);
r[16]=rows(pg16);

@ Vector (number of different other's adjusted guesses x 1) @
opg1=ones((gam[1,5]-gam[1,4])+1,1);
opg2=ones((gam[2,5]-gam[2,4])+1,1);
opg3=ones((gam[3,5]-gam[3,4])+1,1);
opg4=ones((gam[4,5]-gam[4,4])+1,1);
opg5=ones((gam[5,5]-gam[5,4])+1,1);
opg6=ones((gam[6,5]-gam[6,4])+1,1);
opg7=ones((gam[7,5]-gam[7,4])+1,1);
opg8=ones((gam[8,5]-gam[8,4])+1,1);
opg9=ones((gam[9,5]-gam[9,4])+1,1);
opg10=ones((gam[10,5]-gam[10,4])+1,1);
opg11=ones((gam[11,5]-gam[11,4])+1,1);
opg12=ones((gam[12,5]-gam[12,4])+1,1);
opg13=ones((gam[13,5]-gam[13,4])+1,1);
opg14=ones((gam[14,5]-gam[14,4])+1,1);
opg15=ones((gam[15,5]-gam[15,4])+1,1);
opg16=ones((gam[16,5]-gam[16,4])+1,1);

@ Number of different other's adjusted integer guesses @
og=zeros(16,1);
og[1]=rows(opg1);
og[2]=rows(opg2);
og[3]=rows(opg3);
og[4]=rows(opg4);
og[5]=rows(opg5);
og[6]=rows(opg6);
og[7]=rows(opg7);
og[8]=rows(opg8);
og[9]=rows(opg9);
og[10]=rows(opg10);
og[11]=rows(opg11);
og[12]=rows(opg12);
og[13]=rows(opg13);
og[14]=rows(opg14);
og[15]=rows(opg15);
og[16]=rows(opg16);

format 2,4;


@ MODULE 1 - computations associated with (4)'s numerator (INTEGER GUESSES) @

@ Stores number of points of the 1st (fp<type>) and 2nd (sp<type>) parts of @
@ the payoff function; L1, D1, and Soph types total is t_#type              @

fp1=zeros(pl,ga); sp1=zeros(pl,ga);
t2=zeros(pl,ga); 
fp3=zeros(pl,ga); sp3=zeros(pl,ga);
fp4=zeros(pl,ga); sp4=zeros(pl,ga);
t5=zeros(pl,ga); 
t6=zeros(pl,ga); 
t7=zeros(pl,ga);

@ Eqlbm type - Numerator (expected payoff) @
fp1[.,.]=(200-abs(A[.,2:17]-(gam[1:16,3]'.*TOG[1:16,2]')));
sp1[.,.]=(100-abs(A[.,2:17]-(gam[1:16,3]'.*TOG[1:16,2]'))./10);

i=1;
do until i > pl;
g=1;
do until g > ga;
if fp1[i,g]<0; fp1[i,g]=0; endif;
if sp1[i,g]<0; sp1[i,g]=0; endif;
g=g+1;
endo;
i=i+1;
endo;
t1=(fp1+sp1);

@ L1 type - Numerator (expected payoff) @
i=1;
do until i > pl;
g=1;
do until g > ga;
k=1;
do until k > og[g];
fp2=(200-abs(A[i,(1+g)]-(gam[g,3]*(gam[g,4]+(k-1)))) );
sp2=(100-abs(A[i,(1+g)]-(gam[g,3]*(gam[g,4]+(k-1))))/10 );
if fp2<0; fp2=0; endif;
if sp2<0; sp2=0; endif;
t2[i,g]=t2[i,g]+(fp2+sp2)*(1/og[g]);
k=k+1;
endo;
g=g+1;
endo;
i=i+1;
endo;

@ L2 type - Numerator (expected payoff) @
fp3[.,.]=(200-abs(A[.,2:17]-(gam[1:16,3]'.*TOG[1:16,4]')));
sp3[.,.]=(100-abs(A[.,2:17]-(gam[1:16,3]'.*TOG[1:16,4]'))./10);

i=1;
do until i > pl;
g=1;
do until g > 16;
if fp3[i,g]<0; fp3[i,g]=0; endif;
if sp3[i,g]<0; sp3[i,g]=0; endif;
g=g+1;
endo;
i=i+1;
endo;
t3=(fp3+sp3);

@ L3 type - Numerator (expected payoff) @
fp4[.,.]=(200-abs(A[.,2:17]-(gam[1:16,3]'.*TOG[1:16,5]')));
sp4[.,.]=(100-abs(A[.,2:17]-(gam[1:16,3]'.*TOG[1:16,5]'))./10);

i=1;
do until i > pl;
g=1;
do until g > 16;
if fp4[i,g]<0; fp4[i,g]=0; endif;
if sp4[i,g]<0; sp4[i,g]=0; endif;
g=g+1;
endo;
i=i+1;
endo;
t4=(fp4+sp4);

@ D1 type - Numerator (expected payoff) @
i=1;
do until i> pl;
g=1;
do until g > ga;
if g<=8; h=8; else; h=-8; endif;
d1pg=(BRD[(g+h),3]-BRD[(g+h),2])+1;
k=1;
do until k > d1pg;
fp5=(200-abs(A[i,(1+g)]-(gam[g,3]*(BRD[(g+h),2]+(k-1)))) );
sp5=(100-abs(A[i,(1+g)]-(gam[g,3]*(BRD[(g+h),2]+(k-1))))/10 );
if fp5<0; fp5=0; endif;
if sp5<0; sp5=0; endif;
t5[i,g]=t5[i,g]+(fp5+sp5)*(1/d1pg);
k=k+1;
endo;
g=g+1;
endo;
i=i+1;
endo;

@ D2 type - Numerator (expected payoff) @
i=1;
do until i> pl;
g=1;
do until g > ga;
if g<=8; h=8; else; h=-8; endif;
d2pg=(BRD[(g+h),5]-BRD[(g+h),4])+1;
k=1;
do until k > d2pg;
fp6=(200-abs(A[i,(1+g)]-(gam[g,3]*(BRD[(g+h),4]+(k-1)))) );
sp6=(100-abs(A[i,(1+g)]-(gam[g,3]*(BRD[(g+h),4]+(k-1))))/10 );
if fp6<0; fp6=0; endif;
if sp6<0; sp6=0; endif;
t6[i,g]=t6[i,g]+(fp6+sp6)*(1/d2pg);
k=k+1;
endo;
g=g+1;
endo;
i=i+1;
endo;

@ Sophisticated type - Numerator (expected payoff) @
i=1;
do until i> pl;
g=1;
do until g > ga;
if g<=8; h=8; else; h=-8; endif;
k=1;
do until k > og[g];
fp7=(200-abs(A[i,(1+g)]-(gam[g,3]*(gam[g,4]+(k-1)))) );
sp7=(100-abs(A[i,(1+g)]-(gam[g,3]*(gam[g,4]+(k-1))))/10 );
fr=0;
j=1;
do while j<=pl;
if A[j,(1+g+h)]>=(gam[g,4]+(k-1));
 if A[j,(1+g+h)]<(gam[g,4]+(k));
 fr=fr+1;
 endif;
endif; 
j=j+1;
endo;
if fp7<0; fp7=0; endif;
if sp7<0; sp7=0; endif;
t7[i,g]=t7[i,g]+(fp7+sp7)*(fr/pl);
k=k+1;
endo;
g=g+1;
endo;
i=i+1;
endo;


format /m1/rd 2,3;

output file=c:\GG_AER_2006\t1TypeEstNumW1.jnk reset; t1; output off;
output file=c:\GG_AER_2006\t2TypeEstNumW1.jnk reset; t2; output off;
output file=c:\GG_AER_2006\t3TypeEstNumW1.jnk reset; t3; output off;
output file=c:\GG_AER_2006\t4TypeEstNumW1.jnk reset; t4; output off;
output file=c:\GG_AER_2006\t5TypeEstNumW1.jnk reset; t5; output off;
output file=c:\GG_AER_2006\t6TypeEstNumW1.jnk reset; t6; output off;
output file=c:\GG_AER_2006\t7TypeEstNumW1.jnk reset; t7; output off;

@ END OF MODULE 1 @

@ MODULE 2 - computations associated with (4)'s denominator (INTEGER GUESSES) @

@ Sets the number of own possible guesses by game allowing for 7 types @
@ Each matrix corresponds to one of the 16 games                       @
@ Note that the entries for L1, D1, D2, and Sophisticated, 2nd, 5th,   @
@ 6th, and 7th columns are not useful                                  @

dfp1=zeros((gam[1,2]-gam[1,1])+1,7);  
dfp2=zeros((gam[2,2]-gam[2,1])+1,7);  
dfp3=zeros((gam[3,2]-gam[3,1])+1,7);  
dfp4=zeros((gam[4,2]-gam[4,1])+1,7);  
dfp5=zeros((gam[5,2]-gam[5,1])+1,7);  
dfp6=zeros((gam[6,2]-gam[6,1])+1,7);  
dfp7=zeros((gam[7,2]-gam[7,1])+1,7);  
dfp8=zeros((gam[8,2]-gam[8,1])+1,7);  
dfp9=zeros((gam[9,2]-gam[9,1])+1,7);  
dfp10=zeros((gam[10,2]-gam[10,1])+1,7);  
dfp11=zeros((gam[11,2]-gam[11,1])+1,7);  
dfp12=zeros((gam[12,2]-gam[12,1])+1,7);  
dfp13=zeros((gam[13,2]-gam[13,1])+1,7);  
dfp14=zeros((gam[14,2]-gam[14,1])+1,7);  
dfp15=zeros((gam[15,2]-gam[15,1])+1,7);  
dfp16=zeros((gam[16,2]-gam[16,1])+1,7);  

pge=zeros(16,7);

g=1;
do until g>16;
ro=1;
do until ro > r[g];
calc=zeros(2,7);
calc[1,1:6]=(200-abs((gam[g,1]+(ro-1))-(gam[g,3]*TOG[g,2:7])) );
calc[2,1:6]=(100-abs((gam[g,1]+(ro-1))-(gam[g,3]*TOG[g,2:7]))./10 );

j=1;
do until j > 7;

if j==2; 
@ L1 type - Denominator (expected payoff) @
calc[1,j]=0;calc[2,j]=0;
k=1;
do until k > og[g];
fp2=(200-abs((gam[g,1]+(ro-1))-(gam[g,3]*(gam[g,4]+(k-1)))) );
sp2=(100-abs((gam[g,1]+(ro-1))-(gam[g,3]*(gam[g,4]+(k-1))))/10 );
if fp2<0; fp2=0; endif;
if sp2<0; sp2=0; endif;
calc[1,j]=calc[1,j]+(fp2+sp2)*(1/og[g]);
k=k+1;
endo;
@ End of L1 type - Denominator @
endif;

if j==5;
@ D1 type - Denominator (expected payoff) @
calc[1,j]=0;calc[2,j]=0;
if g<=8; h=8; else; h=-8; endif;
d1pg=(BRD[(g+h),3]-BRD[(g+h),2])+1;
k=1;
do until k > d1pg;
fp5=(200-abs((gam[g,1]+(ro-1))-(gam[g,3]*(BRD[(g+h),2]+(k-1)))) );
sp5=(100-abs((gam[g,1]+(ro-1))-(gam[g,3]*(BRD[(g+h),2]+(k-1))))/10 );
if fp5<0; fp5=0; endif;
if sp5<0; sp5=0; endif;
calc[1,j]=calc[1,j]+(fp5+sp5)*(1/d1pg);
k=k+1;
endo;
@ End of D1 type - Denominator @
endif;

if j==6;
@ D2 type - Denominator (expected payoff) @
calc[1,j]=0;calc[2,j]=0;
if g<=8; h=8; else; h=-8; endif;
d2pg=(BRD[(g+h),5]-BRD[(g+h),4])+1;
k=1;
do until k > d2pg;
fp6=(200-abs((gam[g,1]+(ro-1))-(gam[g,3]*(BRD[(g+h),4]+(k-1)))) );
sp6=(100-abs((gam[g,1]+(ro-1))-(gam[g,3]*(BRD[(g+h),4]+(k-1))))/10 );
if fp6<0; fp6=0; endif;
if sp6<0; sp6=0; endif;
calc[1,j]=calc[1,j]+(fp6+sp6)*(1/d2pg);
k=k+1;
endo;
@ End of D2 type - Denominator @
endif;

if j==7;
@ Sophisticated type - Denominator (expected payoff) @
calc[1,j]=0;calc[2,j]=0;
if g<=8; h=8; else; h=-8; endif;
k=1;
do until k > og[g];
fp7=(200-abs((gam[g,1]+(ro-1))-(gam[g,3]*(gam[g,4]+(k-1)))) );
sp7=(100-abs((gam[g,1]+(ro-1))-(gam[g,3]*(gam[g,4]+(k-1))))/10 );
fr=0;
i=1;
do while i<=pl;
if A[j,(1+g+h)]>=(gam[g,4]+(k-1));
 if A[j,(1+g+h)]<(gam[g,4]+(k));
 fr=fr+1;
 endif;
endif; 
i=i+1;
endo;
if fp7<0; fp7=0; endif;
if sp7<0; sp7=0; endif;  
calc[1,j]=calc[1,j]+(fp7+sp7)*(fr/pl);
k=k+1;
endo;
@ End of Sophisticated type - Denominator @
endif;

if g==1;
if calc[1,j]<0; dfp1[ro,j]=0; elseif calc[1,j]>=0; dfp1[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp1[ro,j]=dfp1[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp1[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==2;
if calc[1,j]<0; dfp2[ro,j]=0; elseif calc[1,j]>=0; dfp2[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp2[ro,j]=dfp2[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp2[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==3;
if calc[1,j]<0; dfp3[ro,j]=0; elseif calc[1,j]>=0; dfp3[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp3[ro,j]=dfp3[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp3[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==4;
if calc[1,j]<0; dfp4[ro,j]=0; elseif calc[1,j]>=0; dfp4[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp4[ro,j]=dfp4[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp4[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==5;
if calc[1,j]<0; dfp5[ro,j]=0; elseif calc[1,j]>=0; dfp5[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp5[ro,j]=dfp5[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp5[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==6;
if calc[1,j]<0; dfp6[ro,j]=0; elseif calc[1,j]>=0; dfp6[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp6[ro,j]=dfp6[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp6[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==7;
if calc[1,j]<0; dfp7[ro,j]=0; elseif calc[1,j]>=0; dfp7[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp7[ro,j]=dfp7[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp7[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==8;
if calc[1,j]<0; dfp8[ro,j]=0; elseif calc[1,j]>=0; dfp8[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp8[ro,j]=dfp8[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp8[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==9;
if calc[1,j]<0; dfp9[ro,j]=0; elseif calc[1,j]>=0; dfp9[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp9[ro,j]=dfp9[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp9[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==10;
if calc[1,j]<0; dfp10[ro,j]=0; elseif calc[1,j]>=0; dfp10[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp10[ro,j]=dfp10[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp10[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==11;
if calc[1,j]<0; dfp11[ro,j]=0; elseif calc[1,j]>=0; dfp11[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp11[ro,j]=dfp11[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp11[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==12;
if calc[1,j]<0; dfp12[ro,j]=0; elseif calc[1,j]>=0; dfp12[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp12[ro,j]=dfp12[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp12[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==13;
if calc[1,j]<0; dfp13[ro,j]=0; elseif calc[1,j]>=0; dfp13[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp13[ro,j]=dfp13[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp13[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==14;
if calc[1,j]<0; dfp14[ro,j]=0; elseif calc[1,j]>=0; dfp14[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp14[ro,j]=dfp14[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp14[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==15;
if calc[1,j]<0; dfp15[ro,j]=0; elseif calc[1,j]>=0; dfp15[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp15[ro,j]=dfp15[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp15[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==16;
if calc[1,j]<0; dfp16[ro,j]=0; elseif calc[1,j]>=0; dfp16[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp16[ro,j]=dfp16[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(TPG[g,j+1]-0.5); 
if (gam[g,1]+(ro-1))<=(TPG[g,j+1]+0.5);
dfp16[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;

endif;
j=j+1;
endo;
ro=ro+1;
endo;
g=g+1;
endo;

format /m1/rd 2,3;

output file=c:\GG_AER_2006\g1TypeEstDenW1.jnk reset; dfp1; output off;
output file=c:\GG_AER_2006\g2TypeEstDenW1.jnk reset; dfp2; output off;
output file=c:\GG_AER_2006\g3TypeEstDenW1.jnk reset; dfp3; output off;
output file=c:\GG_AER_2006\g4TypeEstDenW1.jnk reset; dfp4; output off;
output file=c:\GG_AER_2006\g5TypeEstDenW1.jnk reset; dfp5; output off;
output file=c:\GG_AER_2006\g6TypeEstDenW1.jnk reset; dfp6; output off;
output file=c:\GG_AER_2006\g7TypeEstDenW1.jnk reset; dfp7; output off;
output file=c:\GG_AER_2006\g8TypeEstDenW1.jnk reset; dfp8; output off;
output file=c:\GG_AER_2006\g9TypeEstDenW1.jnk reset; dfp9; output off;
output file=c:\GG_AER_2006\g10TypeEstDenW1.jnk reset; dfp10; output off;
output file=c:\GG_AER_2006\g11TypeEstDenW1.jnk reset; dfp11; output off;
output file=c:\GG_AER_2006\g12TypeEstDenW1.jnk reset; dfp12; output off;
output file=c:\GG_AER_2006\g13TypeEstDenW1.jnk reset; dfp13; output off;
output file=c:\GG_AER_2006\g14TypeEstDenW1.jnk reset; dfp14; output off;
output file=c:\GG_AER_2006\g15TypeEstDenW1.jnk reset; dfp15; output off;
output file=c:\GG_AER_2006\g16TypeEstDenW1.jnk reset; dfp16; output off;
output file=c:\GG_AER_2006\pgeTypeEstDenW1.jnk reset; pge; output off;

@ END OF MODULE 2 @


@ PRE SET-UP - MODULES 3 AND 4 @

dfp1=zeros((gam[1,2]-gam[1,1])+1,7);  
dfp2=zeros((gam[2,2]-gam[2,1])+1,7);  
dfp3=zeros((gam[3,2]-gam[3,1])+1,7);  
dfp4=zeros((gam[4,2]-gam[4,1])+1,7);  
dfp5=zeros((gam[5,2]-gam[5,1])+1,7);  
dfp6=zeros((gam[6,2]-gam[6,1])+1,7);  
dfp7=zeros((gam[7,2]-gam[7,1])+1,7);  
dfp8=zeros((gam[8,2]-gam[8,1])+1,7);  
dfp9=zeros((gam[9,2]-gam[9,1])+1,7);  
dfp10=zeros((gam[10,2]-gam[10,1])+1,7);  
dfp11=zeros((gam[11,2]-gam[11,1])+1,7);  
dfp12=zeros((gam[12,2]-gam[12,1])+1,7);  
dfp13=zeros((gam[13,2]-gam[13,1])+1,7);  
dfp14=zeros((gam[14,2]-gam[14,1])+1,7);  
dfp15=zeros((gam[15,2]-gam[15,1])+1,7);  
dfp16=zeros((gam[16,2]-gam[16,1])+1,7);  

load dfp1[rows(pg1),7]=c:\GG_AER_2006\g1TypeEstDenW1.jnk;
load dfp2[rows(pg2),7]=c:\GG_AER_2006\g2TypeEstDenW1.jnk;
load dfp3[rows(pg3),7]=c:\GG_AER_2006\g3TypeEstDenW1.jnk;
load dfp4[rows(pg4),7]=c:\GG_AER_2006\g4TypeEstDenW1.jnk;
load dfp5[rows(pg5),7]=c:\GG_AER_2006\g5TypeEstDenW1.jnk;
load dfp6[rows(pg6),7]=c:\GG_AER_2006\g6TypeEstDenW1.jnk;
load dfp7[rows(pg7),7]=c:\GG_AER_2006\g7TypeEstDenW1.jnk;
load dfp8[rows(pg8),7]=c:\GG_AER_2006\g8TypeEstDenW1.jnk;
load dfp9[rows(pg9),7]=c:\GG_AER_2006\g9TypeEstDenW1.jnk;
load dfp10[rows(pg10),7]=c:\GG_AER_2006\g10TypeEstDenW1.jnk;
load dfp11[rows(pg11),7]=c:\GG_AER_2006\g11TypeEstDenW1.jnk;
load dfp12[rows(pg12),7]=c:\GG_AER_2006\g12TypeEstDenW1.jnk;
load dfp13[rows(pg13),7]=c:\GG_AER_2006\g13TypeEstDenW1.jnk;
load dfp14[rows(pg14),7]=c:\GG_AER_2006\g14TypeEstDenW1.jnk;
load dfp15[rows(pg15),7]=c:\GG_AER_2006\g15TypeEstDenW1.jnk;
load dfp16[rows(pg16),7]=c:\GG_AER_2006\g16TypeEstDenW1.jnk;

load t1[pl,ga]=c:\GG_AER_2006\t1TypeEstNumW1.jnk;
load t2[pl,ga]=c:\GG_AER_2006\t2TypeEstNumW1.jnk;
load t3[pl,ga]=c:\GG_AER_2006\t3TypeEstNumW1.jnk;
load t4[pl,ga]=c:\GG_AER_2006\t4TypeEstNumW1.jnk;
load t5[pl,ga]=c:\GG_AER_2006\t5TypeEstNumW1.jnk;
load t6[pl,ga]=c:\GG_AER_2006\t6TypeEstNumW1.jnk;
load t7[pl,ga]=c:\GG_AER_2006\t7TypeEstNumW1.jnk;

z=z~t1~t2~t3~t4~t5~t6~t7; 

load pge[16,7]=c:\GG_AER_2006\pgeTypeEstDenW1.jnk;


@ Subjects' estimated log-likelihoods given each of the 7 types @
@ Lambda (logit specficication parameter) estimates             @
blot=ones(pl,7);
lam=zeros(pl,7);

blot=(-100000)*blot;

@ Lambda equal to zero restricted model: subjects' estimated @
@ log-likelihoods given each of the 7 types                  @
loz=ones(pl,7);

@ Log-likelihoods estimates for the restricted models        @
@ (i) lambda = 0 and error rate is +-=1 (200/201) (column 2) @
@ (ii) error rate is +-=1 (200/201) (column 3), (column 4    @
@ has the lambda estimate for this restricted model)         @
ra=ones(pl,4);

@ Subjects' estimated (best) types, column 1 is Sub ID, column 2 identifies @
@ best type, column 3 is estimated log-likelihood, column 4 is estimated    @
@ lambda, column 5 is number of correct guesses, column 6 is estimated      @
@ log-likehidood in the lambda equal to zero restricted model               @
bts=zeros(pl,6);

@ Subjects' estimated types: Chi-squared tests (column 1 is subject ID)           @ 
@ (i) lambda = 0 hypothesis - columns 2 and 3 are test statistic and p-value      @
@ (ii) error rate = 1 hypothesis - columns 4 and 5 are test statistic and p-value @
@ (iii) (i)+(ii) hypotheses - columns 6 and 7 are test statistic and p-value      @
tch=zeros(pl,7);

@ END OF SET UP - MODULES 3 AND 4 @


@ MODULE 3 - Computes loglikelihoods of each of the subjects'  @
@ guesses given each of the 7 types, identifying the best type @
@ and estimating the error rate and logit (lambda) parameters. @
@ Estimates the restricted model with lambda equal to zero.    @

s=1;
do while s<=pl;

@ Estimated lambda parameters (one for each type) @
b=zeros(7,1);

ty=1;
do while ty<=7;

b[ty,1]=0;
do while b[ty,1]<=24;

if ty==1;
l1=exp(mcf*b[1,1]*z[s,9])*(1/(sumc(exp(mcf*b[1,1]*dfp1[.,1]))-pge[1,1])); 
l2=exp(mcf*b[1,1]*z[s,10])*(1/(sumc(exp(mcf*b[1,1]*dfp2[.,1]))-pge[2,1]));
l3=exp(mcf*b[1,1]*z[s,11])*(1/(sumc(exp(mcf*b[1,1]*dfp3[.,1]))-pge[3,1]));
l4=exp(mcf*b[1,1]*z[s,12])*(1/(sumc(exp(mcf*b[1,1]*dfp4[.,1]))-pge[4,1]));
l5=exp(mcf*b[1,1]*z[s,13])*(1/(sumc(exp(mcf*b[1,1]*dfp5[.,1]))-pge[5,1]));
l6=exp(mcf*b[1,1]*z[s,14])*(1/(sumc(exp(mcf*b[1,1]*dfp6[.,1]))-pge[6,1]));
l7=exp(mcf*b[1,1]*z[s,15])*(1/(sumc(exp(mcf*b[1,1]*dfp7[.,1]))-pge[7,1]));
l8=exp(mcf*b[1,1]*z[s,16])*(1/(sumc(exp(mcf*b[1,1]*dfp8[.,1]))-pge[8,1]));
l9=exp(mcf*b[1,1]*z[s,17])*(1/(sumc(exp(mcf*b[1,1]*dfp9[.,1]))-pge[9,1]));
l10=exp(mcf*b[1,1]*z[s,18])*(1/(sumc(exp(mcf*b[1,1]*dfp10[.,1]))-pge[10,1]));
l11=exp(mcf*b[1,1]*z[s,19])*(1/(sumc(exp(mcf*b[1,1]*dfp11[.,1]))-pge[11,1]));
l12=exp(mcf*b[1,1]*z[s,20])*(1/(sumc(exp(mcf*b[1,1]*dfp12[.,1]))-pge[12,1]));
l13=exp(mcf*b[1,1]*z[s,21])*(1/(sumc(exp(mcf*b[1,1]*dfp13[.,1]))-pge[13,1]));
l14=exp(mcf*b[1,1]*z[s,22])*(1/(sumc(exp(mcf*b[1,1]*dfp14[.,1]))-pge[14,1]));
l15=exp(mcf*b[1,1]*z[s,23])*(1/(sumc(exp(mcf*b[1,1]*dfp15[.,1]))-pge[15,1]));
l16=exp(mcf*b[1,1]*z[s,24])*(1/(sumc(exp(mcf*b[1,1]*dfp16[.,1]))-pge[16,1]));

elseif ty==2;
l1=exp(mcf*b[2,1]*z[s,25])*(1/(sumc(exp(mcf*b[2,1]*dfp1[.,2]))-pge[1,2]));
l2=exp(mcf*b[2,1]*z[s,26])*(1/(sumc(exp(mcf*b[2,1]*dfp2[.,2]))-pge[2,2]));
l3=exp(mcf*b[2,1]*z[s,27])*(1/(sumc(exp(mcf*b[2,1]*dfp3[.,2]))-pge[3,2]));
l4=exp(mcf*b[2,1]*z[s,28])*(1/(sumc(exp(mcf*b[2,1]*dfp4[.,2]))-pge[4,2]));
l5=exp(mcf*b[2,1]*z[s,29])*(1/(sumc(exp(mcf*b[2,1]*dfp5[.,2]))-pge[5,2]));
l6=exp(mcf*b[2,1]*z[s,30])*(1/(sumc(exp(mcf*b[2,1]*dfp6[.,2]))-pge[6,2]));
l7=exp(mcf*b[2,1]*z[s,31])*(1/(sumc(exp(mcf*b[2,1]*dfp7[.,2]))-pge[7,2]));
l8=exp(mcf*b[2,1]*z[s,32])*(1/(sumc(exp(mcf*b[2,1]*dfp8[.,2]))-pge[8,2]));
l9=exp(mcf*b[2,1]*z[s,33])*(1/(sumc(exp(mcf*b[2,1]*dfp9[.,2]))-pge[9,2]));
l10=exp(mcf*b[2,1]*z[s,34])*(1/(sumc(exp(mcf*b[2,1]*dfp10[.,2]))-pge[10,2]));
l11=exp(mcf*b[2,1]*z[s,35])*(1/(sumc(exp(mcf*b[2,1]*dfp11[.,2]))-pge[11,2]));
l12=exp(mcf*b[2,1]*z[s,36])*(1/(sumc(exp(mcf*b[2,1]*dfp12[.,2]))-pge[12,2]));
l13=exp(mcf*b[2,1]*z[s,37])*(1/(sumc(exp(mcf*b[2,1]*dfp13[.,2]))-pge[13,2]));
l14=exp(mcf*b[2,1]*z[s,38])*(1/(sumc(exp(mcf*b[2,1]*dfp14[.,2]))-pge[14,2]));
l15=exp(mcf*b[2,1]*z[s,39])*(1/(sumc(exp(mcf*b[2,1]*dfp15[.,2]))-pge[15,2]));
l16=exp(mcf*b[2,1]*z[s,40])*(1/(sumc(exp(mcf*b[2,1]*dfp16[.,2]))-pge[16,2]));

elseif ty==3;
l1=exp(mcf*b[3,1]*z[s,41])*(1/(sumc(exp(mcf*b[3,1]*dfp1[.,3]))-pge[1,3]));
l2=exp(mcf*b[3,1]*z[s,42])*(1/(sumc(exp(mcf*b[3,1]*dfp2[.,3]))-pge[2,3]));
l3=exp(mcf*b[3,1]*z[s,43])*(1/(sumc(exp(mcf*b[3,1]*dfp3[.,3]))-pge[3,3]));
l4=exp(mcf*b[3,1]*z[s,44])*(1/(sumc(exp(mcf*b[3,1]*dfp4[.,3]))-pge[4,3]));
l5=exp(mcf*b[3,1]*z[s,45])*(1/(sumc(exp(mcf*b[3,1]*dfp5[.,3]))-pge[5,3]));
l6=exp(mcf*b[3,1]*z[s,46])*(1/(sumc(exp(mcf*b[3,1]*dfp6[.,3]))-pge[6,3]));
l7=exp(mcf*b[3,1]*z[s,47])*(1/(sumc(exp(mcf*b[3,1]*dfp7[.,3]))-pge[7,3]));
l8=exp(mcf*b[3,1]*z[s,48])*(1/(sumc(exp(mcf*b[3,1]*dfp8[.,3]))-pge[8,3]));
l9=exp(mcf*b[3,1]*z[s,49])*(1/(sumc(exp(mcf*b[3,1]*dfp9[.,3]))-pge[9,3]));
l10=exp(mcf*b[3,1]*z[s,50])*(1/(sumc(exp(mcf*b[3,1]*dfp10[.,3]))-pge[10,3]));
l11=exp(mcf*b[3,1]*z[s,51])*(1/(sumc(exp(mcf*b[3,1]*dfp11[.,3]))-pge[11,3]));
l12=exp(mcf*b[3,1]*z[s,52])*(1/(sumc(exp(mcf*b[3,1]*dfp12[.,3]))-pge[12,3]));
l13=exp(mcf*b[3,1]*z[s,53])*(1/(sumc(exp(mcf*b[3,1]*dfp13[.,3]))-pge[13,3]));
l14=exp(mcf*b[3,1]*z[s,54])*(1/(sumc(exp(mcf*b[3,1]*dfp14[.,3]))-pge[14,3]));
l15=exp(mcf*b[3,1]*z[s,55])*(1/(sumc(exp(mcf*b[3,1]*dfp15[.,3]))-pge[15,3]));
l16=exp(mcf*b[3,1]*z[s,56])*(1/(sumc(exp(mcf*b[3,1]*dfp16[.,3]))-pge[16,3]));

elseif ty==4;
l1=exp(mcf*b[4,1]*z[s,57])*(1/(sumc(exp(mcf*b[4,1]*dfp1[.,4]))-pge[1,4]));
l2=exp(mcf*b[4,1]*z[s,58])*(1/(sumc(exp(mcf*b[4,1]*dfp2[.,4]))-pge[2,4]));
l3=exp(mcf*b[4,1]*z[s,59])*(1/(sumc(exp(mcf*b[4,1]*dfp3[.,4]))-pge[3,4]));
l4=exp(mcf*b[4,1]*z[s,60])*(1/(sumc(exp(mcf*b[4,1]*dfp4[.,4]))-pge[4,4]));
l5=exp(mcf*b[4,1]*z[s,61])*(1/(sumc(exp(mcf*b[4,1]*dfp5[.,4]))-pge[5,4]));
l6=exp(mcf*b[4,1]*z[s,62])*(1/(sumc(exp(mcf*b[4,1]*dfp6[.,4]))-pge[6,4]));
l7=exp(mcf*b[4,1]*z[s,63])*(1/(sumc(exp(mcf*b[4,1]*dfp7[.,4]))-pge[7,4]));
l8=exp(mcf*b[4,1]*z[s,64])*(1/(sumc(exp(mcf*b[4,1]*dfp8[.,4]))-pge[8,4]));
l9=exp(mcf*b[4,1]*z[s,65])*(1/(sumc(exp(mcf*b[4,1]*dfp9[.,4]))-pge[9,4]));
l10=exp(mcf*b[4,1]*z[s,66])*(1/(sumc(exp(mcf*b[4,1]*dfp10[.,4]))-pge[10,4]));
l11=exp(mcf*b[4,1]*z[s,67])*(1/(sumc(exp(mcf*b[4,1]*dfp11[.,4]))-pge[11,4]));
l12=exp(mcf*b[4,1]*z[s,68])*(1/(sumc(exp(mcf*b[4,1]*dfp12[.,4]))-pge[12,4]));
l13=exp(mcf*b[4,1]*z[s,69])*(1/(sumc(exp(mcf*b[4,1]*dfp13[.,4]))-pge[13,4]));
l14=exp(mcf*b[4,1]*z[s,70])*(1/(sumc(exp(mcf*b[4,1]*dfp14[.,4]))-pge[14,4]));
l15=exp(mcf*b[4,1]*z[s,71])*(1/(sumc(exp(mcf*b[4,1]*dfp15[.,4]))-pge[15,4]));
l16=exp(mcf*b[4,1]*z[s,72])*(1/(sumc(exp(mcf*b[4,1]*dfp16[.,4]))-pge[16,4]));

elseif ty==5;
l1=exp(mcf*b[5,1]*z[s,73])*(1/(sumc(exp(mcf*b[5,1]*dfp1[.,5]))-pge[1,5]));
l2=exp(mcf*b[5,1]*z[s,74])*(1/(sumc(exp(mcf*b[5,1]*dfp2[.,5]))-pge[2,5]));
l3=exp(mcf*b[5,1]*z[s,75])*(1/(sumc(exp(mcf*b[5,1]*dfp3[.,5]))-pge[3,5]));
l4=exp(mcf*b[5,1]*z[s,76])*(1/(sumc(exp(mcf*b[5,1]*dfp4[.,5]))-pge[4,5]));
l5=exp(mcf*b[5,1]*z[s,77])*(1/(sumc(exp(mcf*b[5,1]*dfp5[.,5]))-pge[5,5]));
l6=exp(mcf*b[5,1]*z[s,78])*(1/(sumc(exp(mcf*b[5,1]*dfp6[.,5]))-pge[6,5]));
l7=exp(mcf*b[5,1]*z[s,79])*(1/(sumc(exp(mcf*b[5,1]*dfp7[.,5]))-pge[7,5]));
l8=exp(mcf*b[5,1]*z[s,80])*(1/(sumc(exp(mcf*b[5,1]*dfp8[.,5]))-pge[8,5]));
l9=exp(mcf*b[5,1]*z[s,81])*(1/(sumc(exp(mcf*b[5,1]*dfp9[.,5]))-pge[9,5]));
l10=exp(mcf*b[5,1]*z[s,82])*(1/(sumc(exp(mcf*b[5,1]*dfp10[.,5]))-pge[10,5]));
l11=exp(mcf*b[5,1]*z[s,83])*(1/(sumc(exp(mcf*b[5,1]*dfp11[.,5]))-pge[11,5]));
l12=exp(mcf*b[5,1]*z[s,84])*(1/(sumc(exp(mcf*b[5,1]*dfp12[.,5]))-pge[12,5]));
l13=exp(mcf*b[5,1]*z[s,85])*(1/(sumc(exp(mcf*b[5,1]*dfp13[.,5]))-pge[13,5]));
l14=exp(mcf*b[5,1]*z[s,86])*(1/(sumc(exp(mcf*b[5,1]*dfp14[.,5]))-pge[14,5]));
l15=exp(mcf*b[5,1]*z[s,87])*(1/(sumc(exp(mcf*b[5,1]*dfp15[.,5]))-pge[15,5]));
l16=exp(mcf*b[5,1]*z[s,88])*(1/(sumc(exp(mcf*b[5,1]*dfp16[.,5]))-pge[16,5]));

elseif ty==6;
l1=exp(mcf*b[6,1]*z[s,89])*(1/(sumc(exp(mcf*b[6,1]*dfp1[.,6]))-pge[1,6]));
l2=exp(mcf*b[6,1]*z[s,90])*(1/(sumc(exp(mcf*b[6,1]*dfp2[.,6]))-pge[2,6]));
l3=exp(mcf*b[6,1]*z[s,91])*(1/(sumc(exp(mcf*b[6,1]*dfp3[.,6]))-pge[3,6]));
l4=exp(mcf*b[6,1]*z[s,92])*(1/(sumc(exp(mcf*b[6,1]*dfp4[.,6]))-pge[4,6]));
l5=exp(mcf*b[6,1]*z[s,93])*(1/(sumc(exp(mcf*b[6,1]*dfp5[.,6]))-pge[5,6]));
l6=exp(mcf*b[6,1]*z[s,94])*(1/(sumc(exp(mcf*b[6,1]*dfp6[.,6]))-pge[6,6]));
l7=exp(mcf*b[6,1]*z[s,95])*(1/(sumc(exp(mcf*b[6,1]*dfp7[.,6]))-pge[7,6]));
l8=exp(mcf*b[6,1]*z[s,96])*(1/(sumc(exp(mcf*b[6,1]*dfp8[.,6]))-pge[8,6]));
l9=exp(mcf*b[6,1]*z[s,97])*(1/(sumc(exp(mcf*b[6,1]*dfp9[.,6]))-pge[9,6]));
l10=exp(mcf*b[6,1]*z[s,98])*(1/(sumc(exp(mcf*b[6,1]*dfp10[.,6]))-pge[10,6]));
l11=exp(mcf*b[6,1]*z[s,99])*(1/(sumc(exp(mcf*b[6,1]*dfp11[.,6]))-pge[11,6]));
l12=exp(mcf*b[6,1]*z[s,100])*(1/(sumc(exp(mcf*b[6,1]*dfp12[.,6]))-pge[12,6]));
l13=exp(mcf*b[6,1]*z[s,101])*(1/(sumc(exp(mcf*b[6,1]*dfp13[.,6]))-pge[13,6]));
l14=exp(mcf*b[6,1]*z[s,102])*(1/(sumc(exp(mcf*b[6,1]*dfp14[.,6]))-pge[14,6]));
l15=exp(mcf*b[6,1]*z[s,103])*(1/(sumc(exp(mcf*b[6,1]*dfp15[.,6]))-pge[15,6]));
l16=exp(mcf*b[6,1]*z[s,104])*(1/(sumc(exp(mcf*b[6,1]*dfp16[.,6]))-pge[16,6]));

elseif ty==7;
l1=exp(mcf*b[7,1]*z[s,105])*(1/(sumc(exp(mcf*b[7,1]*dfp1[.,7]))-pge[1,7]));
l2=exp(mcf*b[7,1]*z[s,106])*(1/(sumc(exp(mcf*b[7,1]*dfp2[.,7]))-pge[2,7]));
l3=exp(mcf*b[7,1]*z[s,107])*(1/(sumc(exp(mcf*b[7,1]*dfp3[.,7]))-pge[3,7]));
l4=exp(mcf*b[7,1]*z[s,108])*(1/(sumc(exp(mcf*b[7,1]*dfp4[.,7]))-pge[4,7]));
l5=exp(mcf*b[7,1]*z[s,109])*(1/(sumc(exp(mcf*b[7,1]*dfp5[.,7]))-pge[5,7]));
l6=exp(mcf*b[7,1]*z[s,110])*(1/(sumc(exp(mcf*b[7,1]*dfp6[.,7]))-pge[6,7]));
l7=exp(mcf*b[7,1]*z[s,111])*(1/(sumc(exp(mcf*b[7,1]*dfp7[.,7]))-pge[7,7]));
l8=exp(mcf*b[7,1]*z[s,112])*(1/(sumc(exp(mcf*b[7,1]*dfp8[.,7]))-pge[8,7]));
l9=exp(mcf*b[7,1]*z[s,113])*(1/(sumc(exp(mcf*b[7,1]*dfp9[.,7]))-pge[9,7]));
l10=exp(mcf*b[7,1]*z[s,114])*(1/(sumc(exp(mcf*b[7,1]*dfp10[.,7]))-pge[10,7]));
l11=exp(mcf*b[7,1]*z[s,115])*(1/(sumc(exp(mcf*b[7,1]*dfp11[.,7]))-pge[11,7]));
l12=exp(mcf*b[7,1]*z[s,116])*(1/(sumc(exp(mcf*b[7,1]*dfp12[.,7]))-pge[12,7]));
l13=exp(mcf*b[7,1]*z[s,117])*(1/(sumc(exp(mcf*b[7,1]*dfp13[.,7]))-pge[13,7]));
l14=exp(mcf*b[7,1]*z[s,118])*(1/(sumc(exp(mcf*b[7,1]*dfp14[.,7]))-pge[14,7]));
l15=exp(mcf*b[7,1]*z[s,119])*(1/(sumc(exp(mcf*b[7,1]*dfp15[.,7]))-pge[15,7]));
l16=exp(mcf*b[7,1]*z[s,120])*(1/(sumc(exp(mcf*b[7,1]*dfp16[.,7]))-pge[16,7]));

endif;

if A[s,2]>=(TPG[1,(ty+1)]-0.5); if A[s,2]<=(TPG[1,(ty+1)]+0.5); 
l1[.,1]=1;  endif; endif;
if A[s,3]>=(TPG[2,(ty+1)]-0.5); if A[s,3]<=(TPG[2,(ty+1)]+0.5); 
l2[.,1]=1;  endif; endif;
if A[s,4]>=(TPG[3,(ty+1)]-0.5); if A[s,4]<=(TPG[3,(ty+1)]+0.5); 
l3[.,1]=1;  endif; endif;
if A[s,5]>=(TPG[4,(ty+1)]-0.5); if A[s,5]<=(TPG[4,(ty+1)]+0.5); 
l4[.,1]=1;  endif; endif;
if A[s,6]>=(TPG[5,(ty+1)]-0.5); if A[s,6]<=(TPG[5,(ty+1)]+0.5); 
l5[.,1]=1;  endif; endif;
if A[s,7]>=(TPG[6,(ty+1)]-0.5); if A[s,7]<=(TPG[6,(ty+1)]+0.5); 
l6[.,1]=1;  endif; endif;
if A[s,8]>=(TPG[7,(ty+1)]-0.5); if A[s,8]<=(TPG[7,(ty+1)]+0.5); 
l7[.,1]=1;  endif; endif;
if A[s,9]>=(TPG[8,(ty+1)]-0.5); if A[s,9]<=(TPG[8,(ty+1)]+0.5); 
l8[.,1]=1;  endif; endif;
if A[s,10]>=(TPG[9,(ty+1)]-0.5); if A[s,10]<=(TPG[9,(ty+1)]+0.5); 
l9[.,1]=1;  endif; endif;
if A[s,11]>=(TPG[10,(ty+1)]-0.5); if A[s,11]<=(TPG[10,(ty+1)]+0.5); 
l10[.,1]=1;  endif; endif;
if A[s,12]>=(TPG[11,(ty+1)]-0.5); if A[s,12]<=(TPG[11,(ty+1)]+0.5); 
l11[.,1]=1;  endif; endif;
if A[s,13]>=(TPG[12,(ty+1)]-0.5); if A[s,13]<=(TPG[12,(ty+1)]+0.5); 
l12[.,1]=1;  endif; endif;
if A[s,14]>=(TPG[13,(ty+1)]-0.5); if A[s,14]<=(TPG[13,(ty+1)]+0.5); 
l13[.,1]=1;  endif; endif;
if A[s,15]>=(TPG[14,(ty+1)]-0.5); if A[s,15]<=(TPG[14,(ty+1)]+0.5); 
l14[.,1]=1;  endif; endif;
if A[s,16]>=(TPG[15,(ty+1)]-0.5); if A[s,16]<=(TPG[15,(ty+1)]+0.5); 
l15[.,1]=1;  endif; endif;
if A[s,17]>=(TPG[16,(ty+1)]-0.5); if A[s,17]<=(TPG[16,(ty+1)]+0.5); 
l16[.,1]=1;  endif; endif;

if z[s,(1+ty)]==0;
 ltot=ln(l1)+ln(l2)+ln(l3)+ln(l4)+ln(l5)+ln(l6)+ln(l7)+ln(l8)+
      ln(l9)+ln(l10)+ln(l11)+ln(l12)+ln(l13)+ln(l14)+ln(l15)+ln(l16);
elseif z[s,(1+ty)]>0 and z[s,(1+ty)]<16;
 ltot=(16-z[s,(1+ty)])*ln(16-z[s,(1+ty)])+z[s,(1+ty)]*ln(z[s,(1+ty)])-16*ln(16)+ln(l1)+ln(l2)+ln(l3)+ln(l4)+ln(l5)+ln(l6)+
 ln(l7)+ln(l8)+ln(l9)+ln(l10)+ln(l11)+ln(l12)+ln(l13)+ln(l14)+ln(l15)+ln(l16);
elseif z[s,(1+ty)]==16;
 ltot=ln(l1)+ln(l2)+ln(l3)+ln(l4)+ln(l5)+ln(l6)+
 ln(l7)+ln(l8)+ln(l9)+ln(l10)+ln(l11)+ln(l12)+ln(l13)+ln(l14)+ln(l15)+ln(l16);
endif;

if ltot > blot[s,ty];
 blot[s,ty]=ltot;
 lam[s,ty]=b[ty,1];
endif;

if b[ty,1]==0;
 loz[s,ty]=ltot;
endif;

if lam[s,ty]<(b[ty,1]-2);
 b[ty,1]=24;
endif;

b[ty,1]=b[ty,1]+0.01;
endo;


ty=ty+1;
endo;

@ Stores best type, log-lik, logit parameter estimate @
bts[s,1]=A[s,1];
bts[s,2]=maxindc(blot[s,.]');
bts[s,3]=maxc(blot[s,.]');
bts[s,4]=lam[s,bts[s,2]];
bts[s,5]=z[s,(1+bts[s,2])];
bts[s,6]=loz[s,bts[s,2]];

@ Chi-square tests of the null hypotheses of the restricted models @
tch[s,1]=A[s,1]; 
tch[s,2]=2*(bts[s,3]-bts[s,6]);
tch[s,3]=cdfchic(tch[s,2],1);


s=s+1;
endo;

format /m1/rd 6,4;
output file=c:\GG_AER_2006\Estimatedloglikelihoods_guesses_alltypes.jnk reset;
blot;

output off;

format /m1/rd 6,4;
output file=c:\GG_AER_2006\TyEstResAGGDGOSuNOMBestTypeW1.jnk reset;
bts;

output off;


@ END OF MODULE 3 @


@ MODULE 4 - Tests for the following restricted models      @
@ (i) epsilon equals 1; (ii) epsilon equals 1 and the logit @
@ parameter is equal to zero, for the best type found above @

s=1;
do while s<=pl;

@ Lambda estimates for each of the 7 types @
b=zeros(7,1);

ra[s,1]=A[s,1];
ra[s,3]=-1000000000000;

ty=1;
do while ty<=7;

b[ty,1]=0;
do while b[ty,1]<=16;

if ty==1;
l1=exp(mcf*b[1,1]*z[s,9])*(1/(sumc(exp(mcf*b[1,1]*dfp1[.,1]))-pge[1,1])); 
l2=exp(mcf*b[1,1]*z[s,10])*(1/(sumc(exp(mcf*b[1,1]*dfp2[.,1]))-pge[2,1]));
l3=exp(mcf*b[1,1]*z[s,11])*(1/(sumc(exp(mcf*b[1,1]*dfp3[.,1]))-pge[3,1]));
l4=exp(mcf*b[1,1]*z[s,12])*(1/(sumc(exp(mcf*b[1,1]*dfp4[.,1]))-pge[4,1]));
l5=exp(mcf*b[1,1]*z[s,13])*(1/(sumc(exp(mcf*b[1,1]*dfp5[.,1]))-pge[5,1]));
l6=exp(mcf*b[1,1]*z[s,14])*(1/(sumc(exp(mcf*b[1,1]*dfp6[.,1]))-pge[6,1]));
l7=exp(mcf*b[1,1]*z[s,15])*(1/(sumc(exp(mcf*b[1,1]*dfp7[.,1]))-pge[7,1]));
l8=exp(mcf*b[1,1]*z[s,16])*(1/(sumc(exp(mcf*b[1,1]*dfp8[.,1]))-pge[8,1]));
l9=exp(mcf*b[1,1]*z[s,17])*(1/(sumc(exp(mcf*b[1,1]*dfp9[.,1]))-pge[9,1]));
l10=exp(mcf*b[1,1]*z[s,18])*(1/(sumc(exp(mcf*b[1,1]*dfp10[.,1]))-pge[10,1]));
l11=exp(mcf*b[1,1]*z[s,19])*(1/(sumc(exp(mcf*b[1,1]*dfp11[.,1]))-pge[11,1]));
l12=exp(mcf*b[1,1]*z[s,20])*(1/(sumc(exp(mcf*b[1,1]*dfp12[.,1]))-pge[12,1]));
l13=exp(mcf*b[1,1]*z[s,21])*(1/(sumc(exp(mcf*b[1,1]*dfp13[.,1]))-pge[13,1]));
l14=exp(mcf*b[1,1]*z[s,22])*(1/(sumc(exp(mcf*b[1,1]*dfp14[.,1]))-pge[14,1]));
l15=exp(mcf*b[1,1]*z[s,23])*(1/(sumc(exp(mcf*b[1,1]*dfp15[.,1]))-pge[15,1]));
l16=exp(mcf*b[1,1]*z[s,24])*(1/(sumc(exp(mcf*b[1,1]*dfp16[.,1]))-pge[16,1]));

elseif ty==2;
l1=exp(mcf*b[2,1]*z[s,25])*(1/(sumc(exp(mcf*b[2,1]*dfp1[.,2]))-pge[1,2]));
l2=exp(mcf*b[2,1]*z[s,26])*(1/(sumc(exp(mcf*b[2,1]*dfp2[.,2]))-pge[2,2]));
l3=exp(mcf*b[2,1]*z[s,27])*(1/(sumc(exp(mcf*b[2,1]*dfp3[.,2]))-pge[3,2]));
l4=exp(mcf*b[2,1]*z[s,28])*(1/(sumc(exp(mcf*b[2,1]*dfp4[.,2]))-pge[4,2]));
l5=exp(mcf*b[2,1]*z[s,29])*(1/(sumc(exp(mcf*b[2,1]*dfp5[.,2]))-pge[5,2]));
l6=exp(mcf*b[2,1]*z[s,30])*(1/(sumc(exp(mcf*b[2,1]*dfp6[.,2]))-pge[6,2]));
l7=exp(mcf*b[2,1]*z[s,31])*(1/(sumc(exp(mcf*b[2,1]*dfp7[.,2]))-pge[7,2]));
l8=exp(mcf*b[2,1]*z[s,32])*(1/(sumc(exp(mcf*b[2,1]*dfp8[.,2]))-pge[8,2]));
l9=exp(mcf*b[2,1]*z[s,33])*(1/(sumc(exp(mcf*b[2,1]*dfp9[.,2]))-pge[9,2]));
l10=exp(mcf*b[2,1]*z[s,34])*(1/(sumc(exp(mcf*b[2,1]*dfp10[.,2]))-pge[10,2]));
l11=exp(mcf*b[2,1]*z[s,35])*(1/(sumc(exp(mcf*b[2,1]*dfp11[.,2]))-pge[11,2]));
l12=exp(mcf*b[2,1]*z[s,36])*(1/(sumc(exp(mcf*b[2,1]*dfp12[.,2]))-pge[12,2]));
l13=exp(mcf*b[2,1]*z[s,37])*(1/(sumc(exp(mcf*b[2,1]*dfp13[.,2]))-pge[13,2]));
l14=exp(mcf*b[2,1]*z[s,38])*(1/(sumc(exp(mcf*b[2,1]*dfp14[.,2]))-pge[14,2]));
l15=exp(mcf*b[2,1]*z[s,39])*(1/(sumc(exp(mcf*b[2,1]*dfp15[.,2]))-pge[15,2]));
l16=exp(mcf*b[2,1]*z[s,40])*(1/(sumc(exp(mcf*b[2,1]*dfp16[.,2]))-pge[16,2]));

elseif ty==3;
l1=exp(mcf*b[3,1]*z[s,41])*(1/(sumc(exp(mcf*b[3,1]*dfp1[.,3]))-pge[1,3]));
l2=exp(mcf*b[3,1]*z[s,42])*(1/(sumc(exp(mcf*b[3,1]*dfp2[.,3]))-pge[2,3]));
l3=exp(mcf*b[3,1]*z[s,43])*(1/(sumc(exp(mcf*b[3,1]*dfp3[.,3]))-pge[3,3]));
l4=exp(mcf*b[3,1]*z[s,44])*(1/(sumc(exp(mcf*b[3,1]*dfp4[.,3]))-pge[4,3]));
l5=exp(mcf*b[3,1]*z[s,45])*(1/(sumc(exp(mcf*b[3,1]*dfp5[.,3]))-pge[5,3]));
l6=exp(mcf*b[3,1]*z[s,46])*(1/(sumc(exp(mcf*b[3,1]*dfp6[.,3]))-pge[6,3]));
l7=exp(mcf*b[3,1]*z[s,47])*(1/(sumc(exp(mcf*b[3,1]*dfp7[.,3]))-pge[7,3]));
l8=exp(mcf*b[3,1]*z[s,48])*(1/(sumc(exp(mcf*b[3,1]*dfp8[.,3]))-pge[8,3]));
l9=exp(mcf*b[3,1]*z[s,49])*(1/(sumc(exp(mcf*b[3,1]*dfp9[.,3]))-pge[9,3]));
l10=exp(mcf*b[3,1]*z[s,50])*(1/(sumc(exp(mcf*b[3,1]*dfp10[.,3]))-pge[10,3]));
l11=exp(mcf*b[3,1]*z[s,51])*(1/(sumc(exp(mcf*b[3,1]*dfp11[.,3]))-pge[11,3]));
l12=exp(mcf*b[3,1]*z[s,52])*(1/(sumc(exp(mcf*b[3,1]*dfp12[.,3]))-pge[12,3]));
l13=exp(mcf*b[3,1]*z[s,53])*(1/(sumc(exp(mcf*b[3,1]*dfp13[.,3]))-pge[13,3]));
l14=exp(mcf*b[3,1]*z[s,54])*(1/(sumc(exp(mcf*b[3,1]*dfp14[.,3]))-pge[14,3]));
l15=exp(mcf*b[3,1]*z[s,55])*(1/(sumc(exp(mcf*b[3,1]*dfp15[.,3]))-pge[15,3]));
l16=exp(mcf*b[3,1]*z[s,56])*(1/(sumc(exp(mcf*b[3,1]*dfp16[.,3]))-pge[16,3]));

elseif ty==4;
l1=exp(mcf*b[4,1]*z[s,57])*(1/(sumc(exp(mcf*b[4,1]*dfp1[.,4]))-pge[1,4]));
l2=exp(mcf*b[4,1]*z[s,58])*(1/(sumc(exp(mcf*b[4,1]*dfp2[.,4]))-pge[2,4]));
l3=exp(mcf*b[4,1]*z[s,59])*(1/(sumc(exp(mcf*b[4,1]*dfp3[.,4]))-pge[3,4]));
l4=exp(mcf*b[4,1]*z[s,60])*(1/(sumc(exp(mcf*b[4,1]*dfp4[.,4]))-pge[4,4]));
l5=exp(mcf*b[4,1]*z[s,61])*(1/(sumc(exp(mcf*b[4,1]*dfp5[.,4]))-pge[5,4]));
l6=exp(mcf*b[4,1]*z[s,62])*(1/(sumc(exp(mcf*b[4,1]*dfp6[.,4]))-pge[6,4]));
l7=exp(mcf*b[4,1]*z[s,63])*(1/(sumc(exp(mcf*b[4,1]*dfp7[.,4]))-pge[7,4]));
l8=exp(mcf*b[4,1]*z[s,64])*(1/(sumc(exp(mcf*b[4,1]*dfp8[.,4]))-pge[8,4]));
l9=exp(mcf*b[4,1]*z[s,65])*(1/(sumc(exp(mcf*b[4,1]*dfp9[.,4]))-pge[9,4]));
l10=exp(mcf*b[4,1]*z[s,66])*(1/(sumc(exp(mcf*b[4,1]*dfp10[.,4]))-pge[10,4]));
l11=exp(mcf*b[4,1]*z[s,67])*(1/(sumc(exp(mcf*b[4,1]*dfp11[.,4]))-pge[11,4]));
l12=exp(mcf*b[4,1]*z[s,68])*(1/(sumc(exp(mcf*b[4,1]*dfp12[.,4]))-pge[12,4]));
l13=exp(mcf*b[4,1]*z[s,69])*(1/(sumc(exp(mcf*b[4,1]*dfp13[.,4]))-pge[13,4]));
l14=exp(mcf*b[4,1]*z[s,70])*(1/(sumc(exp(mcf*b[4,1]*dfp14[.,4]))-pge[14,4]));
l15=exp(mcf*b[4,1]*z[s,71])*(1/(sumc(exp(mcf*b[4,1]*dfp15[.,4]))-pge[15,4]));
l16=exp(mcf*b[4,1]*z[s,72])*(1/(sumc(exp(mcf*b[4,1]*dfp16[.,4]))-pge[16,4]));

elseif ty==5;
l1=exp(mcf*b[5,1]*z[s,73])*(1/(sumc(exp(mcf*b[5,1]*dfp1[.,5]))-pge[1,5]));
l2=exp(mcf*b[5,1]*z[s,74])*(1/(sumc(exp(mcf*b[5,1]*dfp2[.,5]))-pge[2,5]));
l3=exp(mcf*b[5,1]*z[s,75])*(1/(sumc(exp(mcf*b[5,1]*dfp3[.,5]))-pge[3,5]));
l4=exp(mcf*b[5,1]*z[s,76])*(1/(sumc(exp(mcf*b[5,1]*dfp4[.,5]))-pge[4,5]));
l5=exp(mcf*b[5,1]*z[s,77])*(1/(sumc(exp(mcf*b[5,1]*dfp5[.,5]))-pge[5,5]));
l6=exp(mcf*b[5,1]*z[s,78])*(1/(sumc(exp(mcf*b[5,1]*dfp6[.,5]))-pge[6,5]));
l7=exp(mcf*b[5,1]*z[s,79])*(1/(sumc(exp(mcf*b[5,1]*dfp7[.,5]))-pge[7,5]));
l8=exp(mcf*b[5,1]*z[s,80])*(1/(sumc(exp(mcf*b[5,1]*dfp8[.,5]))-pge[8,5]));
l9=exp(mcf*b[5,1]*z[s,81])*(1/(sumc(exp(mcf*b[5,1]*dfp9[.,5]))-pge[9,5]));
l10=exp(mcf*b[5,1]*z[s,82])*(1/(sumc(exp(mcf*b[5,1]*dfp10[.,5]))-pge[10,5]));
l11=exp(mcf*b[5,1]*z[s,83])*(1/(sumc(exp(mcf*b[5,1]*dfp11[.,5]))-pge[11,5]));
l12=exp(mcf*b[5,1]*z[s,84])*(1/(sumc(exp(mcf*b[5,1]*dfp12[.,5]))-pge[12,5]));
l13=exp(mcf*b[5,1]*z[s,85])*(1/(sumc(exp(mcf*b[5,1]*dfp13[.,5]))-pge[13,5]));
l14=exp(mcf*b[5,1]*z[s,86])*(1/(sumc(exp(mcf*b[5,1]*dfp14[.,5]))-pge[14,5]));
l15=exp(mcf*b[5,1]*z[s,87])*(1/(sumc(exp(mcf*b[5,1]*dfp15[.,5]))-pge[15,5]));
l16=exp(mcf*b[5,1]*z[s,88])*(1/(sumc(exp(mcf*b[5,1]*dfp16[.,5]))-pge[16,5]));

elseif ty==6;
l1=exp(mcf*b[6,1]*z[s,89])*(1/(sumc(exp(mcf*b[6,1]*dfp1[.,6]))-pge[1,6]));
l2=exp(mcf*b[6,1]*z[s,90])*(1/(sumc(exp(mcf*b[6,1]*dfp2[.,6]))-pge[2,6]));
l3=exp(mcf*b[6,1]*z[s,91])*(1/(sumc(exp(mcf*b[6,1]*dfp3[.,6]))-pge[3,6]));
l4=exp(mcf*b[6,1]*z[s,92])*(1/(sumc(exp(mcf*b[6,1]*dfp4[.,6]))-pge[4,6]));
l5=exp(mcf*b[6,1]*z[s,93])*(1/(sumc(exp(mcf*b[6,1]*dfp5[.,6]))-pge[5,6]));
l6=exp(mcf*b[6,1]*z[s,94])*(1/(sumc(exp(mcf*b[6,1]*dfp6[.,6]))-pge[6,6]));
l7=exp(mcf*b[6,1]*z[s,95])*(1/(sumc(exp(mcf*b[6,1]*dfp7[.,6]))-pge[7,6]));
l8=exp(mcf*b[6,1]*z[s,96])*(1/(sumc(exp(mcf*b[6,1]*dfp8[.,6]))-pge[8,6]));
l9=exp(mcf*b[6,1]*z[s,97])*(1/(sumc(exp(mcf*b[6,1]*dfp9[.,6]))-pge[9,6]));
l10=exp(mcf*b[6,1]*z[s,98])*(1/(sumc(exp(mcf*b[6,1]*dfp10[.,6]))-pge[10,6]));
l11=exp(mcf*b[6,1]*z[s,99])*(1/(sumc(exp(mcf*b[6,1]*dfp11[.,6]))-pge[11,6]));
l12=exp(mcf*b[6,1]*z[s,100])*(1/(sumc(exp(mcf*b[6,1]*dfp12[.,6]))-pge[12,6]));
l13=exp(mcf*b[6,1]*z[s,101])*(1/(sumc(exp(mcf*b[6,1]*dfp13[.,6]))-pge[13,6]));
l14=exp(mcf*b[6,1]*z[s,102])*(1/(sumc(exp(mcf*b[6,1]*dfp14[.,6]))-pge[14,6]));
l15=exp(mcf*b[6,1]*z[s,103])*(1/(sumc(exp(mcf*b[6,1]*dfp15[.,6]))-pge[15,6]));
l16=exp(mcf*b[6,1]*z[s,104])*(1/(sumc(exp(mcf*b[6,1]*dfp16[.,6]))-pge[16,6]));

elseif ty==7;
l1=exp(mcf*b[7,1]*z[s,105])*(1/(sumc(exp(mcf*b[7,1]*dfp1[.,7]))-pge[1,7]));
l2=exp(mcf*b[7,1]*z[s,106])*(1/(sumc(exp(mcf*b[7,1]*dfp2[.,7]))-pge[2,7]));
l3=exp(mcf*b[7,1]*z[s,107])*(1/(sumc(exp(mcf*b[7,1]*dfp3[.,7]))-pge[3,7]));
l4=exp(mcf*b[7,1]*z[s,108])*(1/(sumc(exp(mcf*b[7,1]*dfp4[.,7]))-pge[4,7]));
l5=exp(mcf*b[7,1]*z[s,109])*(1/(sumc(exp(mcf*b[7,1]*dfp5[.,7]))-pge[5,7]));
l6=exp(mcf*b[7,1]*z[s,110])*(1/(sumc(exp(mcf*b[7,1]*dfp6[.,7]))-pge[6,7]));
l7=exp(mcf*b[7,1]*z[s,111])*(1/(sumc(exp(mcf*b[7,1]*dfp7[.,7]))-pge[7,7]));
l8=exp(mcf*b[7,1]*z[s,112])*(1/(sumc(exp(mcf*b[7,1]*dfp8[.,7]))-pge[8,7]));
l9=exp(mcf*b[7,1]*z[s,113])*(1/(sumc(exp(mcf*b[7,1]*dfp9[.,7]))-pge[9,7]));
l10=exp(mcf*b[7,1]*z[s,114])*(1/(sumc(exp(mcf*b[7,1]*dfp10[.,7]))-pge[10,7]));
l11=exp(mcf*b[7,1]*z[s,115])*(1/(sumc(exp(mcf*b[7,1]*dfp11[.,7]))-pge[11,7]));
l12=exp(mcf*b[7,1]*z[s,116])*(1/(sumc(exp(mcf*b[7,1]*dfp12[.,7]))-pge[12,7]));
l13=exp(mcf*b[7,1]*z[s,117])*(1/(sumc(exp(mcf*b[7,1]*dfp13[.,7]))-pge[13,7]));
l14=exp(mcf*b[7,1]*z[s,118])*(1/(sumc(exp(mcf*b[7,1]*dfp14[.,7]))-pge[14,7]));
l15=exp(mcf*b[7,1]*z[s,119])*(1/(sumc(exp(mcf*b[7,1]*dfp15[.,7]))-pge[15,7]));
l16=exp(mcf*b[7,1]*z[s,120])*(1/(sumc(exp(mcf*b[7,1]*dfp16[.,7]))-pge[16,7]));

endif;

if A[s,2]>=(TPG[1,(ty+1)]-0.5); if A[s,2]<=(TPG[1,(ty+1)]+0.5); l1[.,1]=(1/201); endif; endif;
if A[s,3]>=(TPG[2,(ty+1)]-0.5); if A[s,3]<=(TPG[2,(ty+1)]+0.5); l2[.,1]=(1/201); endif; endif;
if A[s,4]>=(TPG[3,(ty+1)]-0.5); if A[s,4]<=(TPG[3,(ty+1)]+0.5); l3[.,1]=(1/201); endif; endif;
if A[s,5]>=(TPG[4,(ty+1)]-0.5); if A[s,5]<=(TPG[4,(ty+1)]+0.5); l4[.,1]=(1/201); endif; endif;
if A[s,6]>=(TPG[5,(ty+1)]-0.5); if A[s,6]<=(TPG[5,(ty+1)]+0.5); l5[.,1]=(1/201); endif; endif;
if A[s,7]>=(TPG[6,(ty+1)]-0.5); if A[s,7]<=(TPG[6,(ty+1)]+0.5); l6[.,1]=(1/201); endif; endif;
if A[s,8]>=(TPG[7,(ty+1)]-0.5); if A[s,8]<=(TPG[7,(ty+1)]+0.5); l7[.,1]=(1/201); endif; endif;
if A[s,9]>=(TPG[8,(ty+1)]-0.5); if A[s,9]<=(TPG[8,(ty+1)]+0.5); l8[.,1]=(1/201); endif; endif;
if A[s,10]>=(TPG[9,(ty+1)]-0.5); if A[s,10]<=(TPG[9,(ty+1)]+0.5); l9[.,1]=(1/201); endif; endif;
if A[s,11]>=(TPG[10,(ty+1)]-0.5); if A[s,11]<=(TPG[10,(ty+1)]+0.5); l10[.,1]=(1/201); endif; endif;
if A[s,12]>=(TPG[11,(ty+1)]-0.5); if A[s,12]<=(TPG[11,(ty+1)]+0.5); l11[.,1]=(1/201); endif; endif;
if A[s,13]>=(TPG[12,(ty+1)]-0.5); if A[s,13]<=(TPG[12,(ty+1)]+0.5); l12[.,1]=(1/201); endif; endif;
if A[s,14]>=(TPG[13,(ty+1)]-0.5); if A[s,14]<=(TPG[13,(ty+1)]+0.5); l13[.,1]=(1/201); endif; endif;
if A[s,15]>=(TPG[14,(ty+1)]-0.5); if A[s,15]<=(TPG[14,(ty+1)]+0.5); l14[.,1]=(1/201); endif; endif;
if A[s,16]>=(TPG[15,(ty+1)]-0.5); if A[s,16]<=(TPG[15,(ty+1)]+0.5); l15[.,1]=(1/201); endif; endif;
if A[s,17]>=(TPG[16,(ty+1)]-0.5); if A[s,17]<=(TPG[16,(ty+1)]+0.5); l16[.,1]=(1/201); endif; endif;

ltot=ln(l1)+ln(l2)+ln(l3)+ln(l4)+ln(l5)+ln(l6)+ln(l7)+ln(l8)+
      ln(l9)+ln(l10)+ln(l11)+ln(l12)+ln(l13)+ln(l14)+ln(l15)+ln(l16);

if ty==bts[s,2];
  if b[ty,1]==0;
    ra[s,2]=ltot;
    tch[s,4]=2*(bts[s,3]-ra[s,2]);
    tch[s,5]=cdfchic(tch[s,4],2);
   endif;
  if ltot > ra[s,3];
    ra[s,3]=ltot;
    ra[s,4]=b[ty,1];
  endif;
  if ra[s,4]<(b[ty,1]-2);
    b[ty,1]=16;
  endif;      
endif;

b[ty,1]=b[ty,1]+0.01;
endo;

if ty==bts[s,2];
   tch[s,6]=2*(bts[s,3]-ra[s,3]);
   tch[s,7]=cdfchic(tch[s,6],1);
endif;

ty=ty+1;
endo;

s=s+1;
endo;

@ END OF MODULE 4 @


format /m1/rd 6,4;

output file=c:\GG_AER_2006\TypeEstimResultsAGGDGOSuNOMW1.jnk reset;

print "Subjects' Estimated Types (Integer Guesses)";
print;
print "Subjects' estimated (best) types, column 1 is Sub ID, column 2 is";
print "best type (Eq.-1, L1-2,L2-3,L3-4,D1-5,D2-6,So-7),column 3 is estimated ";
print "log-likelihood, column 4 is estimated lambda, column 5 is number of ";
print "correct guesses";
bts[.,1:5];
print;
print "Subjects' estimated types: Chi-squared tests (column 1 is subject ID) ";
print "(i) lambda = 0 hypothesis - columns 2 and 3 are test statistic and p-value";    
print "(ii) error rate = 1 hypothesis - columns 4 and 5 are test statistic and p-value";             
print "(i)+(ii) hypotheses - columns 6 and 7 are test statistic and p-value";
tch;
print;


output off;


@ MODULE 5 - Specification Test - Part I                            @
@ For each subject, estimates a model where each of the opponents'  @
@ guesses are assumed to be a type's guesses (pseudotype). Compares @
@ a subject's estimated type with the likelihood of a subject's     @
@ guesses given the pseudotype                                      @

@ Pseudotypes: log-likelihood estimates @
ptll=ones(pl,88);
ptll=(-100000)*ptll;

@ Pseudotypes: error rates estimates @
ptep=zeros(pl,88);

@ Pseudotypes: lambda parameter estimates @
ptle=zeros(pl,88);

@ Number of pseudotypes that beat a subject's estimated type @
nptbt=zeros(pl,2);

@ PART A - PSEUDOTYPES' IMPLICIT BELIEFS @

@ Subjects' guesses implied beliefs @
igb=zeros(pl,17);

@ Variable indicating whether a subject's guess implied belief in a game @
@ falls outside (I=1) or inside (I=0) a game's lower and upper bounds    @
ingb=zeros(pl,17);

i=1;
do while i <= pl;
 igb[i,1]=A[i,1]; ingb[i,1]=A[i,1];
 g=1;
 do while g <= 16;
  igb[i,g+1]=A[i,1+g]*(1/gam[g,3]);
   if igb[i,g+1]<gam[g,4];     igb[i,g+1]=gam[g,4]; ingb[i,g+1]=1;
   elseif igb[i,g+1]>gam[g,5]; igb[i,g+1]=gam[g,5]; ingb[i,g+1]=1;
   endif;
 g=g+1;
 endo;
i=i+1;
endo;

@ END OF PART A @


@ PART B - Pseudotypes (4)'s numerator's calculations (INTEGER GUESSES) @

fp1=zeros(pl,pl);  sp1=zeros(pl,pl);
fp2=zeros(pl,pl);  sp2=zeros(pl,pl);
fp3=zeros(pl,pl);  sp3=zeros(pl,pl);
fp4=zeros(pl,pl);  sp4=zeros(pl,pl);
fp5=zeros(pl,pl);  sp5=zeros(pl,pl);
fp6=zeros(pl,pl);  sp6=zeros(pl,pl);
fp7=zeros(pl,pl);  sp7=zeros(pl,pl);
fp8=zeros(pl,pl);  sp8=zeros(pl,pl);
fp9=zeros(pl,pl);  sp9=zeros(pl,pl);
fp10=zeros(pl,pl); sp10=zeros(pl,pl);
fp11=zeros(pl,pl); sp11=zeros(pl,pl);
fp12=zeros(pl,pl); sp12=zeros(pl,pl);
fp13=zeros(pl,pl); sp13=zeros(pl,pl);
fp14=zeros(pl,pl); sp14=zeros(pl,pl);
fp15=zeros(pl,pl); sp15=zeros(pl,pl);
fp16=zeros(pl,pl); sp16=zeros(pl,pl);

@ Pseudotypes - Numerator (expected payoff) - Game 1 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp1[i,j]=(200-abs(A[i,2]-(gam[1,3]*igb[j,2])));
sp1[i,j]=(100-abs(A[i,2]-(gam[1,3]*igb[j,2]))./10);
if fp1[i,j]<0; fp1[i,j]=0; endif;
if sp1[i,j]<0; sp1[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t1=(fp1+sp1);

@ Pseudotypes - Numerator (expected payoff) - Game 2 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp2[i,j]=(200-abs(A[i,3]-(gam[2,3]*igb[j,3])));
sp2[i,j]=(100-abs(A[i,3]-(gam[2,3]*igb[j,3]))./10);
if fp2[i,j]<0; fp2[i,j]=0; endif;
if sp2[i,j]<0; sp2[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t2=(fp2+sp2);

@ Pseudotypes - Numerator (expected payoff) - Game 3 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp3[i,j]=(200-abs(A[i,4]-(gam[3,3]*igb[j,4])));
sp3[i,j]=(100-abs(A[i,4]-(gam[3,3]*igb[j,4]))./10);
if fp3[i,j]<0; fp3[i,j]=0; endif;
if sp3[i,j]<0; sp3[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t3=(fp3+sp3);

@ Pseudotypes - Numerator (expected payoff) - Game 4 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp4[i,j]=(200-abs(A[i,5]-(gam[4,3]*igb[j,5])));
sp4[i,j]=(100-abs(A[i,5]-(gam[4,3]*igb[j,5]))./10);
if fp4[i,j]<0; fp4[i,j]=0; endif;
if sp4[i,j]<0; sp4[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t4=(fp4+sp4);

@ Pseudotypes - Numerator (expected payoff) - Game 5 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp5[i,j]=(200-abs(A[i,6]-(gam[5,3]*igb[j,6])));
sp5[i,j]=(100-abs(A[i,6]-(gam[5,3]*igb[j,6]))./10);
if fp5[i,j]<0; fp5[i,j]=0; endif;
if sp5[i,j]<0; sp5[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t5=(fp5+sp5);

@ Pseudotypes - Numerator (expected payoff) - Game 6 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp6[i,j]=(200-abs(A[i,7]-(gam[6,3]*igb[j,7])));
sp6[i,j]=(100-abs(A[i,7]-(gam[6,3]*igb[j,7]))./10);
if fp6[i,j]<0; fp6[i,j]=0; endif;
if sp6[i,j]<0; sp6[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t6=(fp6+sp6);

@ Pseudotypes - Numerator (expected payoff) - Game 7 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp7[i,j]=(200-abs(A[i,8]-(gam[7,3]*igb[j,8])));
sp7[i,j]=(100-abs(A[i,8]-(gam[7,3]*igb[j,8]))./10);
if fp7[i,j]<0; fp7[i,j]=0; endif;
if sp7[i,j]<0; sp7[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t7=(fp7+sp7);

@ Pseudotypes - Numerator (expected payoff) - Game 8 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp8[i,j]=(200-abs(A[i,9]-(gam[8,3]*igb[j,9])));
sp8[i,j]=(100-abs(A[i,9]-(gam[8,3]*igb[j,9]))./10);
if fp8[i,j]<0; fp8[i,j]=0; endif;
if sp8[i,j]<0; sp8[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t8=(fp8+sp8);

@ Pseudotypes - Numerator (expected payoff) - Game 9 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp9[i,j]=(200-abs(A[i,10]-(gam[9,3]*igb[j,10])));
sp9[i,j]=(100-abs(A[i,10]-(gam[9,3]*igb[j,10]))./10);
if fp9[i,j]<0; fp9[i,j]=0; endif;
if sp9[i,j]<0; sp9[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t9=(fp9+sp9);

@ Pseudotypes - Numerator (expected payoff) - Game 10 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp10[i,j]=(200-abs(A[i,11]-(gam[10,3]*igb[j,11])));
sp10[i,j]=(100-abs(A[i,11]-(gam[10,3]*igb[j,11]))./10);
if fp10[i,j]<0; fp10[i,j]=0; endif;
if sp10[i,j]<0; sp10[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t10=(fp10+sp10);

@ Pseudotypes - Numerator (expected payoff) - Game 11 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp11[i,j]=(200-abs(A[i,12]-(gam[11,3]*igb[j,12])));
sp11[i,j]=(100-abs(A[i,12]-(gam[11,3]*igb[j,12]))./10);
if fp11[i,j]<0; fp11[i,j]=0; endif;
if sp11[i,j]<0; sp11[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t11=(fp11+sp11);

@ Pseudotypes - Numerator (expected payoff) - Game 12 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp12[i,j]=(200-abs(A[i,13]-(gam[12,3]*igb[j,13])));
sp12[i,j]=(100-abs(A[i,13]-(gam[12,3]*igb[j,13]))./10);
if fp12[i,j]<0; fp12[i,j]=0; endif;
if sp12[i,j]<0; sp12[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t12=(fp12+sp12);

@ Pseudotypes - Numerator (expected payoff) - Game 13 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp13[i,j]=(200-abs(A[i,14]-(gam[13,3]*igb[j,14])));
sp13[i,j]=(100-abs(A[i,14]-(gam[13,3]*igb[j,14]))./10);
if fp13[i,j]<0; fp13[i,j]=0; endif;
if sp13[i,j]<0; sp13[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t13=(fp13+sp13);

@ Pseudotypes - Numerator (expected payoff) - Game 14 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp14[i,j]=(200-abs(A[i,15]-(gam[14,3]*igb[j,15])));
sp14[i,j]=(100-abs(A[i,15]-(gam[14,3]*igb[j,15]))./10);
if fp14[i,j]<0; fp14[i,j]=0; endif;
if sp14[i,j]<0; sp14[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t14=(fp14+sp14);

@ Pseudotypes - Numerator (expected payoff) - Game 15 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp15[i,j]=(200-abs(A[i,16]-(gam[15,3]*igb[j,16])));
sp15[i,j]=(100-abs(A[i,16]-(gam[15,3]*igb[j,16]))./10);
if fp15[i,j]<0; fp15[i,j]=0; endif;
if sp15[i,j]<0; sp15[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t15=(fp15+sp15);

@ Pseudotypes - Numerator (expected payoff) - Game 16 @
i=1;
do until i > pl;
j=1;
do until j > pl;
fp16[i,j]=(200-abs(A[i,17]-(gam[16,3]*igb[j,17])));
sp16[i,j]=(100-abs(A[i,17]-(gam[16,3]*igb[j,17]))./10);
if fp16[i,j]<0; fp16[i,j]=0; endif;
if sp16[i,j]<0; sp16[i,j]=0; endif;
j=j+1;
endo;
i=i+1;
endo;
t16=(fp16+sp16);

@ Sub-module that saves output of denominator to be used in the future @
output file=c:\GG_AER_2006\t1PSTypeEstNumW1.jnk reset; t1; output off;
output file=c:\GG_AER_2006\t2PSTypeEstNumW1.jnk reset; t2; output off;
output file=c:\GG_AER_2006\t3PSTypeEstNumW1.jnk reset; t3; output off;
output file=c:\GG_AER_2006\t4PSTypeEstNumW1.jnk reset; t4; output off;
output file=c:\GG_AER_2006\t5PSTypeEstNumW1.jnk reset; t5; output off;
output file=c:\GG_AER_2006\t6PSTypeEstNumW1.jnk reset; t6; output off;
output file=c:\GG_AER_2006\t7PSTypeEstNumW1.jnk reset; t7; output off;
output file=c:\GG_AER_2006\t8PSTypeEstNumW1.jnk reset; t8; output off;
output file=c:\GG_AER_2006\t9PSTypeEstNumW1.jnk reset; t9; output off;
output file=c:\GG_AER_2006\t10PSTypeEstNumW1.jnk reset; t10; output off;
output file=c:\GG_AER_2006\t11PSTypeEstNumW1.jnk reset; t11; output off;
output file=c:\GG_AER_2006\t12PSTypeEstNumW1.jnk reset; t12; output off;
output file=c:\GG_AER_2006\t13PSTypeEstNumW1.jnk reset; t13; output off;
output file=c:\GG_AER_2006\t14PSTypeEstNumW1.jnk reset; t14; output off;
output file=c:\GG_AER_2006\t15PSTypeEstNumW1.jnk reset; t15; output off;
output file=c:\GG_AER_2006\t16PSTypeEstNumW1.jnk reset; t16; output off;

@ END OF PART B @

@ PART B - Pseudotypes (4)'s denominator's calculations (INTEGER GUESSES) @

dfp1=zeros((gam[1,2]-gam[1,1])+1,pl);  
dfp2=zeros((gam[2,2]-gam[2,1])+1,pl);  
dfp3=zeros((gam[3,2]-gam[3,1])+1,pl);  
dfp4=zeros((gam[4,2]-gam[4,1])+1,pl);  
dfp5=zeros((gam[5,2]-gam[5,1])+1,pl);  
dfp6=zeros((gam[6,2]-gam[6,1])+1,pl);  
dfp7=zeros((gam[7,2]-gam[7,1])+1,pl);  
dfp8=zeros((gam[8,2]-gam[8,1])+1,pl);  
dfp9=zeros((gam[9,2]-gam[9,1])+1,pl);  
dfp10=zeros((gam[10,2]-gam[10,1])+1,pl);  
dfp11=zeros((gam[11,2]-gam[11,1])+1,pl);  
dfp12=zeros((gam[12,2]-gam[12,1])+1,pl);  
dfp13=zeros((gam[13,2]-gam[13,1])+1,pl);  
dfp14=zeros((gam[14,2]-gam[14,1])+1,pl);  
dfp15=zeros((gam[15,2]-gam[15,1])+1,pl);  
dfp16=zeros((gam[16,2]-gam[16,1])+1,pl);  

pge=zeros(16,pl);

g=1;
do until g>16;
ro=1;
do until ro > r[g];
calc=zeros(2,pl);
calc[1,1:pl]=(200-abs((gam[g,1]+(ro-1))-(gam[g,3]*(igb[1:pl,1+g]')) ) );
calc[2,1:pl]=(100-abs((gam[g,1]+(ro-1))-(gam[g,3]*(igb[1:pl,1+g]')))./10 );
j=1;
do until j > pl;

if g==1;
if calc[1,j]<0; dfp1[ro,j]=0; elseif calc[1,j]>=0; dfp1[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp1[ro,j]=dfp1[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp1[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==2;
if calc[1,j]<0; dfp2[ro,j]=0; elseif calc[1,j]>=0; dfp2[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp2[ro,j]=dfp2[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp2[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==3;
if calc[1,j]<0; dfp3[ro,j]=0; elseif calc[1,j]>=0; dfp3[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp3[ro,j]=dfp3[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp3[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==4;
if calc[1,j]<0; dfp4[ro,j]=0; elseif calc[1,j]>=0; dfp4[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp4[ro,j]=dfp4[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp4[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==5;
if calc[1,j]<0; dfp5[ro,j]=0; elseif calc[1,j]>=0; dfp5[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp5[ro,j]=dfp5[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp5[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==6;
if calc[1,j]<0; dfp6[ro,j]=0; elseif calc[1,j]>=0; dfp6[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp6[ro,j]=dfp6[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp6[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==7;
if calc[1,j]<0; dfp7[ro,j]=0; elseif calc[1,j]>=0; dfp7[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp7[ro,j]=dfp7[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp7[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==8;
if calc[1,j]<0; dfp8[ro,j]=0; elseif calc[1,j]>=0; dfp8[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp8[ro,j]=dfp8[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp8[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==9;
if calc[1,j]<0; dfp9[ro,j]=0; elseif calc[1,j]>=0; dfp9[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp9[ro,j]=dfp9[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp9[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==10;
if calc[1,j]<0; dfp10[ro,j]=0; elseif calc[1,j]>=0; dfp10[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp10[ro,j]=dfp10[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp10[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==11;
if calc[1,j]<0; dfp11[ro,j]=0; elseif calc[1,j]>=0; dfp11[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp11[ro,j]=dfp11[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp11[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==12;
if calc[1,j]<0; dfp12[ro,j]=0; elseif calc[1,j]>=0; dfp12[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp12[ro,j]=dfp12[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp12[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==13;
if calc[1,j]<0; dfp13[ro,j]=0; elseif calc[1,j]>=0; dfp13[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp13[ro,j]=dfp13[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp13[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==14;
if calc[1,j]<0; dfp14[ro,j]=0; elseif calc[1,j]>=0; dfp14[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp14[ro,j]=dfp14[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp14[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==15;
if calc[1,j]<0; dfp15[ro,j]=0; elseif calc[1,j]>=0; dfp15[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp15[ro,j]=dfp15[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp15[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;
elseif g==16;
if calc[1,j]<0; dfp16[ro,j]=0; elseif calc[1,j]>=0; dfp16[ro,j]=calc[1,j]; endif;
if calc[2,j]>=0; dfp16[ro,j]=dfp16[ro,j]+calc[2,j]; endif;
if (gam[g,1]+(ro-1))>=(A[j,g+1]-0.5); 
if (gam[g,1]+(ro-1))<=(A[j,g+1]+0.5);
dfp16[ro,j]=0; pge[g,j]=pge[g,j]+1;
endif;
endif;

endif;
j=j+1;
endo;
ro=ro+1;
endo;
g=g+1;
endo;

@ END OF PART C @


@ PART D - computes log-likelihoods of subjects' guesses given pseudotypes @

load bts[pl,6]=c:\GG_AER_2006\TyEstResAGGDGOSuNOMBestTypeW1.jnk;

i=1;
do while i <=pl;

@ Excludes subjects #309 (42), #405 (55), and #513 (83) @
if i/=42 or i/=55 or i/=83;

@ Loop over subjects whose are pseudotypes @
j=1;
do while j <=pl;

@ Excludes subjects #309 (42), #405 (55), and #513 (83) @
if j/=42 or j/=55 or j/=83;

@ Number of a subject's guesses equal to a pseudotype's guesses @
cg=0;

g=1;
do while g<=16;
if A[i,1+g]<=(A[j,1+g]+0.5);
 if A[i,1+g]>=(A[j,1+g]-0.5);
  cg=cg+1;
 endif;
endif;
g=g+1;
endo;

b=zeros(1,1);
do while b[1,1]<=24;

l1=exp(mcf*b[1,1]*t1[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp1[.,j]))-pge[1,j])); 
l2=exp(mcf*b[1,1]*t2[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp2[.,j]))-pge[2,j]));
l3=exp(mcf*b[1,1]*t3[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp3[.,j]))-pge[3,j]));
l4=exp(mcf*b[1,1]*t4[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp4[.,j]))-pge[4,j]));
l5=exp(mcf*b[1,1]*t5[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp5[.,j]))-pge[5,j]));
l6=exp(mcf*b[1,1]*t6[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp6[.,j]))-pge[6,j]));
l7=exp(mcf*b[1,1]*t7[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp7[.,j]))-pge[7,j]));
l8=exp(mcf*b[1,1]*t8[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp8[.,j]))-pge[8,j]));
l9=exp(mcf*b[1,1]*t9[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp9[.,j]))-pge[9,j]));
l10=exp(mcf*b[1,1]*t10[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp10[.,j]))-pge[10,j]));
l11=exp(mcf*b[1,1]*t11[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp11[.,j]))-pge[11,j]));
l12=exp(mcf*b[1,1]*t12[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp12[.,j]))-pge[12,j]));
l13=exp(mcf*b[1,1]*t13[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp13[.,j]))-pge[13,j]));
l14=exp(mcf*b[1,1]*t14[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp14[.,j]))-pge[14,j]));
l15=exp(mcf*b[1,1]*t15[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp15[.,j]))-pge[15,j]));
l16=exp(mcf*b[1,1]*t16[i,j])*(1/(sumc(exp(mcf*b[1,1]*dfp16[.,j]))-pge[16,j]));

if A[i,2]>=(A[j,2]-0.5); if A[i,2]<=(A[j,2]+0.5); l1[.,1]=1;  endif; endif;
if A[i,3]>=(A[j,3]-0.5); if A[i,3]<=(A[j,3]+0.5); l2[.,1]=1;  endif; endif;
if A[i,4]>=(A[j,4]-0.5); if A[i,4]<=(A[j,4]+0.5); l3[.,1]=1;  endif; endif;
if A[i,5]>=(A[j,5]-0.5); if A[i,5]<=(A[j,5]+0.5); l4[.,1]=1;  endif; endif;
if A[i,6]>=(A[j,6]-0.5); if A[i,6]<=(A[j,6]+0.5); l5[.,1]=1;  endif; endif;
if A[i,7]>=(A[j,7]-0.5); if A[i,7]<=(A[j,7]+0.5); l6[.,1]=1;  endif; endif;
if A[i,8]>=(A[j,8]-0.5); if A[i,8]<=(A[j,8]+0.5); l7[.,1]=1;  endif; endif;
if A[i,9]>=(A[j,9]-0.5); if A[i,9]<=(A[j,9]+0.5); l8[.,1]=1;  endif; endif;
if A[i,10]>=(A[j,10]-0.5); if A[i,10]<=(A[j,10]+0.5); l9[.,1]=1;  endif; endif;
if A[i,11]>=(A[j,11]-0.5); if A[i,11]<=(A[j,11]+0.5); l10[.,1]=1;  endif; endif;
if A[i,12]>=(A[j,12]-0.5); if A[i,12]<=(A[j,12]+0.5); l11[.,1]=1;  endif; endif;
if A[i,13]>=(A[j,13]-0.5); if A[i,13]<=(A[j,13]+0.5); l12[.,1]=1;  endif; endif;
if A[i,14]>=(A[j,14]-0.5); if A[i,14]<=(A[j,14]+0.5); l13[.,1]=1;  endif; endif;
if A[i,15]>=(A[j,15]-0.5); if A[i,15]<=(A[j,15]+0.5); l14[.,1]=1;  endif; endif;
if A[i,16]>=(A[j,16]-0.5); if A[i,16]<=(A[j,16]+0.5); l15[.,1]=1;  endif; endif;
if A[i,17]>=(A[j,17]-0.5); if A[i,17]<=(A[j,17]+0.5); l16[.,1]=1;  endif; endif;

if cg==0;
 ltot=ln(l1)+ln(l2)+ln(l3)+ln(l4)+ln(l5)+ln(l6)+ln(l7)+ln(l8)+
      ln(l9)+ln(l10)+ln(l11)+ln(l12)+ln(l13)+ln(l14)+ln(l15)+ln(l16);
elseif cg>0 and cg<16;
 ltot=(16-cg)*ln(16-cg)+cg*ln(cg)-16*ln(16)+ln(l1)+ln(l2)+ln(l3)+ln(l4)+ln(l5)+ln(l6)+
 ln(l7)+ln(l8)+ln(l9)+ln(l10)+ln(l11)+ln(l12)+ln(l13)+ln(l14)+ln(l15)+ln(l16);
elseif cg==16;
 ltot=ln(l1)+ln(l2)+ln(l3)+ln(l4)+ln(l5)+ln(l6)+
 ln(l7)+ln(l8)+ln(l9)+ln(l10)+ln(l11)+ln(l12)+ln(l13)+ln(l14)+ln(l15)+ln(l16);
endif;

@ Stores the best estimate found so far @
if ltot > ptll[i,j];
 ptll[i,j]=ltot;
 ptle[i,j]=b[1,1];
 ptep[i,j]=(16-cg)/16;
endif;

if ptle[i,j]<(b[1,1]-2);
 b[1,1]=24;
endif;

b[1,1]=b[1,1]+0.01;
endo;

endif;

j=j+1;
endo;

endif;

i=i+1;
endo;

format /m1/rdc 6,4;
output file=c:\GG_AER_2006\PseudotypesLoglikelihoodsW1.jnk reset; 
ptll; 

output off;


